@@ -43,6 +43,7 @@ Example Provider Configuration
 :maintainer: Russell Tolle <russ.tolle@gmail.com>
 :depends: libcloud >= 1.0.0
 """
+
 # pylint: disable=function-redefined
 
 import logging
@@ -60,20 +61,17 @@ import salt.utils.msgpack
 from salt.cloud.libcloudfuncs import *  # pylint: disable=redefined-builtin,wildcard-import,unused-wildcard-import
 from salt.exceptions import SaltCloudSystemExit
 from salt.utils.functools import namespaced_function
-from salt.utils.versions import LooseVersion as _LooseVersion
+from salt.utils.versions import Version
 
 # pylint: disable=import-error
 LIBCLOUD_IMPORT_ERROR = None
 try:
     import libcloud
-    from libcloud.compute.types import Provider
+    from libcloud.common.google import ResourceInUseError, ResourceNotFoundError
     from libcloud.compute.providers import get_driver
-    from libcloud.loadbalancer.types import Provider as Provider_lb
+    from libcloud.compute.types import Provider
     from libcloud.loadbalancer.providers import get_driver as get_driver_lb
-    from libcloud.common.google import (
-        ResourceInUseError,
-        ResourceNotFoundError,
-    )
+    from libcloud.loadbalancer.types import Provider as Provider_lb
 
     HAS_LIBCLOUD = True
 except ImportError:
@@ -110,7 +108,7 @@ def __virtual__():
     if not HAS_LIBCLOUD:
         return False, "apache-libcloud is not installed"
 
-    if _LooseVersion(libcloud.__version__) < _LooseVersion("2.5.0"):
+    if Version(libcloud.__version__) < Version("2.5.0"):
         return False, "The salt-cloud GCE driver requires apache-libcloud>=2.5.0"
 
     if get_configured_provider() is False:
@@ -188,7 +186,7 @@ def get_conn():
         "service_account_private_key", provider, __opts__
     )
     gce = driver(email, private_key, project=project)
-    gce.connection.user_agent_append("{}/{}".format(_UA_PRODUCT, _UA_VERSION))
+    gce.connection.user_agent_append(f"{_UA_PRODUCT}/{_UA_VERSION}")
     return gce
 
 
@@ -396,6 +394,24 @@ def __get_size(conn, vm_):
     return conn.ex_get_size(size, __get_location(conn, vm_))
 
 
+def __get_labels(vm_):
+    """
+    Get configured labels.
+    """
+    l = config.get_cloud_config_value(
+        "ex_labels", vm_, __opts__, default="{}", search_global=False
+    )
+    # Consider warning the user that the labels in the cloud profile
+    # could not be interpreted, bad formatting?
+    try:
+        labels = literal_eval(l)
+    except Exception:  # pylint: disable=W0703
+        labels = None
+    if not labels or not isinstance(labels, dict):
+        labels = None
+    return labels
+
+
 def __get_tags(vm_):
     """
     Get configured tags.
@@ -528,7 +544,7 @@ def _parse_allow(allow):
         pairs = p.split(":")
         if pairs[0].lower() not in ["tcp", "udp", "icmp"]:
             raise SaltCloudSystemExit(
-                "Unsupported protocol {}. Must be tcp, udp, or icmp.".format(pairs[0])
+                f"Unsupported protocol {pairs[0]}. Must be tcp, udp, or icmp."
             )
         if len(pairs) == 1 or pairs[0].lower() == "icmp":
             seen_protos[pairs[0]] = []
@@ -1180,6 +1196,7 @@ def create_address(kwargs=None, call=None):
     name = kwargs["name"]
     ex_region = kwargs["region"]
     ex_address = kwargs.get("address", None)
+    kwargs["region"] = {"name": ex_region.name}
 
     conn = get_conn()
 
@@ -1187,7 +1204,7 @@ def create_address(kwargs=None, call=None):
         "event",
         "create address",
         "salt/cloud/address/creating",
-        args=kwargs,
+        args=salt.utils.data.simple_types_filter(kwargs),
         sock_dir=__opts__["sock_dir"],
         transport=__opts__["transport"],
     )
@@ -1198,7 +1215,7 @@ def create_address(kwargs=None, call=None):
         "event",
         "created address",
         "salt/cloud/address/created",
-        args=kwargs,
+        args=salt.utils.data.simple_types_filter(kwargs),
         sock_dir=__opts__["sock_dir"],
         transport=__opts__["transport"],
     )
@@ -1682,7 +1699,6 @@ def delete_disk(kwargs=None, call=None):
 
 
 def create_disk(kwargs=None, call=None):
-
     """
     Create a new persistent disk. Must specify `disk_name` and `location`,
     and optionally can specify 'disk_type' as pd-standard or pd-ssd, which
@@ -1998,7 +2014,7 @@ def reboot(vm_name, call=None):
     __utils__["cloud.fire_event"](
         "event",
         "reboot instance",
-        "salt/cloud/{}/rebooting".format(vm_name),
+        f"salt/cloud/{vm_name}/rebooting",
         args={"name": vm_name},
         sock_dir=__opts__["sock_dir"],
         transport=__opts__["transport"],
@@ -2009,7 +2025,7 @@ def reboot(vm_name, call=None):
     __utils__["cloud.fire_event"](
         "event",
         "reboot instance",
-        "salt/cloud/{}/rebooted".format(vm_name),
+        f"salt/cloud/{vm_name}/rebooted",
         args={"name": vm_name},
         sock_dir=__opts__["sock_dir"],
         transport=__opts__["transport"],
@@ -2040,7 +2056,7 @@ def start(vm_name, call=None):
     __utils__["cloud.fire_event"](
         "event",
         "start instance",
-        "salt/cloud/{}/starting".format(vm_name),
+        f"salt/cloud/{vm_name}/starting",
         args={"name": vm_name},
         sock_dir=__opts__["sock_dir"],
         transport=__opts__["transport"],
@@ -2051,7 +2067,7 @@ def start(vm_name, call=None):
     __utils__["cloud.fire_event"](
         "event",
         "start instance",
-        "salt/cloud/{}/started".format(vm_name),
+        f"salt/cloud/{vm_name}/started",
         args={"name": vm_name},
         sock_dir=__opts__["sock_dir"],
         transport=__opts__["transport"],
@@ -2080,7 +2096,7 @@ def stop(vm_name, call=None):
     __utils__["cloud.fire_event"](
         "event",
         "stop instance",
-        "salt/cloud/{}/stopping".format(vm_name),
+        f"salt/cloud/{vm_name}/stopping",
         args={"name": vm_name},
         sock_dir=__opts__["sock_dir"],
         transport=__opts__["transport"],
@@ -2091,7 +2107,7 @@ def stop(vm_name, call=None):
     __utils__["cloud.fire_event"](
         "event",
         "stop instance",
-        "salt/cloud/{}/stopped".format(vm_name),
+        f"salt/cloud/{vm_name}/stopped",
         args={"name": vm_name},
         sock_dir=__opts__["sock_dir"],
         transport=__opts__["transport"],
@@ -2129,12 +2145,12 @@ def destroy(vm_name, call=None):
             exc,
             exc_info_on_loglevel=logging.DEBUG,
         )
-        raise SaltCloudSystemExit("Could not find instance {}.".format(vm_name))
+        raise SaltCloudSystemExit(f"Could not find instance {vm_name}.")
 
     __utils__["cloud.fire_event"](
         "event",
         "delete instance",
-        "salt/cloud/{}/deleting".format(vm_name),
+        f"salt/cloud/{vm_name}/deleting",
         args={"name": vm_name},
         sock_dir=__opts__["sock_dir"],
         transport=__opts__["transport"],
@@ -2170,11 +2186,11 @@ def destroy(vm_name, call=None):
             exc,
             exc_info_on_loglevel=logging.DEBUG,
         )
-        raise SaltCloudSystemExit("Could not destroy instance {}.".format(vm_name))
+        raise SaltCloudSystemExit(f"Could not destroy instance {vm_name}.")
     __utils__["cloud.fire_event"](
         "event",
         "delete instance",
-        "salt/cloud/{}/deleted".format(vm_name),
+        f"salt/cloud/{vm_name}/deleted",
         args={"name": vm_name},
         sock_dir=__opts__["sock_dir"],
         transport=__opts__["transport"],
@@ -2253,7 +2269,7 @@ def create_attach_volumes(name, kwargs, call=None):
     """
     if call != "action":
         raise SaltCloudSystemExit(
-            "The create_attach_volumes action must be called with " "-a or --action."
+            "The create_attach_volumes action must be called with -a or --action."
         )
 
     volumes = literal_eval(kwargs["volumes"])
@@ -2263,7 +2279,7 @@ def create_attach_volumes(name, kwargs, call=None):
     letter = ord("a") - 1
 
     for idx, volume in enumerate(volumes):
-        volume_name = "{}-sd{}".format(name, chr(letter + 2 + idx))
+        volume_name = f"{name}-sd{chr(letter + 2 + idx)}"
 
         volume_dict = {
             "disk_name": volume_name,
@@ -2287,8 +2303,8 @@ def request_instance(vm_):
     """
     if not GCE_VM_NAME_REGEX.match(vm_["name"]):
         raise SaltCloudSystemExit(
-            "VM names must start with a letter, only contain letters, numbers, or dashes "
-            "and cannot end in a dash."
+            "VM names must start with a letter, only contain letters, numbers, or"
+            " dashes and cannot end in a dash."
         )
 
     try:
@@ -2322,6 +2338,7 @@ def request_instance(vm_):
         "size": __get_size(conn, vm_),
         "image": __get_image(conn, vm_),
         "location": __get_location(conn, vm_),
+        "ex_labels": __get_labels(vm_),
         "ex_network": __get_network(conn, vm_),
         "ex_subnetwork": __get_subnetwork(vm_),
         "ex_tags": __get_tags(vm_),
@@ -2333,13 +2350,20 @@ def request_instance(vm_):
 
     if external_ip.lower() == "ephemeral":
         external_ip = "ephemeral"
+        vm_["external_ip"] = external_ip
     elif external_ip == "None":
         external_ip = None
+        vm_["external_ip"] = external_ip
     else:
         region = __get_region(conn, vm_)
         external_ip = __create_orget_address(conn, external_ip, region)
+
+        vm_["external_ip"] = {
+            "name": external_ip.name,
+            "address": external_ip.address,
+            "region": external_ip.region.name,
+        }
     kwargs["external_ip"] = external_ip
-    vm_["external_ip"] = external_ip
 
     if LIBCLOUD_VERSION_INFO > (0, 15, 1):
 
