@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Support IPMI commands over LAN. This module does not talk to the local
 systems hardware through IPMI drivers. It uses a python module `pyghmi`.
@@ -31,18 +30,12 @@ systems hardware through IPMI drivers. It uses a python module `pyghmi`.
                                     uid=1
 """
 
-# Import Python Libs
-from __future__ import absolute_import, print_function, unicode_literals
-
-# Import Salt libs
-from salt.ext import six
-
 IMPORT_ERR = None
 try:
-    from pyghmi.ipmi import command
-    from pyghmi.ipmi.private import session
+    from pyghmi.ipmi import command  # nosec
+    from pyghmi.ipmi.private import session  # nosec
 except Exception as ex:  # pylint: disable=broad-except
-    IMPORT_ERR = six.text_type(ex)
+    IMPORT_ERR = str(ex)
 
 __virtualname__ = "ipmi"
 
@@ -64,14 +57,14 @@ def _get_config(**kwargs):
         "api_login_timeout": 2,
     }
     if "__salt__" in globals():
-        config_key = "{0}.config".format(__virtualname__)
+        config_key = f"{__virtualname__}.config"
         config.update(__salt__["config.get"](config_key, {}))
     for k in set(config) & set(kwargs):
         config[k] = kwargs[k]
     return config
 
 
-class _IpmiCommand(object):
+class _IpmiCommand:
     o = None
 
     def __init__(self, **kwargs):
@@ -92,7 +85,7 @@ class _IpmiCommand(object):
             self.o.ipmi_session.logout()
 
 
-class _IpmiSession(object):
+class _IpmiSession:
     o = None
 
     def _onlogon(self, response):
@@ -204,7 +197,7 @@ def set_channel_access(
     access_mode="always",
     privilege_update_mode="non_volatile",
     privilege_level="administrator",
-    **kwargs
+    **kwargs,
 ):
     """
     Set channel access
@@ -394,7 +387,7 @@ def set_user_access(
     link_auth=True,
     ipmi_msg=True,
     privilege_level="administrator",
-    **kwargs
+    **kwargs,
 ):
     """
     Set user access
@@ -903,7 +896,7 @@ def create_user(
     link_auth=True,
     ipmi_msg=True,
     privilege_level="administrator",
-    **kwargs
+    **kwargs,
 ):
     """
     create/ensure a user is created with provided settings.
