@@ -21,14 +21,14 @@ import sys
 import threading
 import time
 
+from tornado import gen
+
 import salt._logging
 import salt.defaults.exitcodes
 import salt.utils.files
 import salt.utils.path
 import salt.utils.platform
 import salt.utils.versions
-from salt.ext.tornado import gen
-from salt.utils.platform import get_machine_identifier as _get_machine_identifier
 
 log = logging.getLogger(__name__)
 
@@ -1169,10 +1169,17 @@ class SubprocessList:
 
     def cleanup(self):
         with self.lock:
-            for proc in self.processes:
-                if proc.is_alive():
-                    continue
-                proc.join()
+            for proc in self.processes[:]:
+                proc.join(0.01)
+                if hasattr(proc, "exitcode"):
+                    # Only processes have exitcode and a close method, threads
+                    # do not.
+                    if proc.exitcode is None:
+                        continue
+                    proc.close()
+                else:
+                    if proc.is_alive():
+                        continue
                 self.processes.remove(proc)
                 self.count -= 1
                 log.debug("Subprocess %s cleaned up", proc.name)
