@@ -556,7 +556,8 @@ class AsyncPubChannel:
             # may have been restarted
             yield self.send_id(self.token, self._reconnected)
             self.connected = True
-            self.event.fire_event({"master": self.opts["master"]}, "__master_connected")
+            if self.event:
+                self.event.fire_event({"master": self.opts["master"]}, "__master_connected")
             if self._reconnected:
                 # On reconnects, fire a master event to notify that the minion is
                 # available.
@@ -639,6 +640,13 @@ class AsyncPubChannel:
                         "Payload decryption failed even after re-authenticating with master %s",
                         self.opts["master_ip"],
                     )
+                    raise tornado.gen.Return(None)
+            if isinstance(payload["load"], (bytes, str)):
+                log.error(
+                    "Discarding load from master %s because it could not be decrypted",
+                    self.opts["master_ip"],
+                )
+                raise tornado.gen.Return(None)
         raise tornado.gen.Return(payload)
 
     def __enter__(self):
