@@ -1,17 +1,11 @@
-# -*- coding: utf-8 -*-
 """
 Support for the Amazon Simple Queue Service.
 """
 
-# Import Python libs
-from __future__ import absolute_import, print_function, unicode_literals
-
 import logging
 
-# Import salt libs
 import salt.utils.json
 import salt.utils.path
-from salt.ext import six
 
 log = logging.getLogger(__name__)
 
@@ -29,7 +23,7 @@ def _region(region):
     """
     Return the region argument.
     """
-    return " --region {r}".format(r=region)
+    return f" --region {region}"
 
 
 def _run_aws(cmd, region, opts, user, **kwargs):
@@ -55,7 +49,7 @@ def _run_aws(cmd, region, opts, user, **kwargs):
     if num:
         kwargs["max-number-of-messages"] = num
 
-    _formatted_args = ['--{0} "{1}"'.format(k, v) for k, v in six.iteritems(kwargs)]
+    _formatted_args = [f'--{k} "{v}"' for k, v in kwargs.items()]
 
     cmd = "aws sqs {cmd} {args} {region} {out}".format(
         cmd=cmd, args=" ".join(_formatted_args), region=_region(region), out=_OUTPUT
@@ -170,6 +164,8 @@ def list_queues(region, opts=None, user=None):
 
     CLI Example:
 
+    .. code-block:: bash
+
         salt '*' aws_sqs.list_queues <region>
 
     """
@@ -200,6 +196,8 @@ def create_queue(name, region, opts=None, user=None):
 
     CLI Example:
 
+    .. code-block:: bash
+
         salt '*' aws_sqs.create_queue <sqs queue> <region>
 
     """
@@ -232,6 +230,8 @@ def delete_queue(name, region, opts=None, user=None):
 
     CLI Example:
 
+    .. code-block:: bash
+
         salt '*' aws_sqs.delete_queue <sqs queue> <region>
 
     """
@@ -245,7 +245,7 @@ def delete_queue(name, region, opts=None, user=None):
         rtn = _run_aws("delete-queue", region=region, opts=opts, user=user, **delete)
         success = True
         err = ""
-        out = "{0} deleted".format(name)
+        out = f"{name} deleted"
 
     else:
         out = ""
@@ -278,6 +278,8 @@ def queue_exists(name, region, opts=None, user=None):
 
     CLI Example:
 
+    .. code-block:: bash
+
         salt '*' aws_sqs.queue_exists <sqs queue> <region>
 
     """
@@ -290,5 +292,5 @@ def _parse_queue_list(list_output):
     """
     Parse the queue to get a dict of name -> URL
     """
-    queues = dict((q.split("/")[-1], q) for q in list_output["stdout"])
+    queues = {q.split("/")[-1]: q for q in list_output["stdout"]}
     return queues
