@@ -48,9 +48,7 @@ def _build_session(username, password, trans_label=None):
 
     if trans_label:
         # pull the trans id from the grain
-        trans_id = __salt__["grains.get"](
-            "bigip_f5_trans:{label}".format(label=trans_label)
-        )
+        trans_id = __salt__["grains.get"](f"bigip_f5_trans:{trans_label}")
 
         if trans_id:
             bigip.headers.update({"X-F5-REST-Coordination-Id": trans_id})
@@ -82,8 +80,10 @@ def _load_connection_error(hostname, error):
 
     ret = {
         "code": None,
-        "content": "Error: Unable to connect to the bigip device: {host}\n{error}".format(
-            host=hostname, error=error
+        "content": (
+            "Error: Unable to connect to the bigip device: {host}\n{error}".format(
+                host=hostname, error=error
+            )
         ),
     }
 
@@ -275,8 +275,9 @@ def start_transaction(hostname, username, password, label):
 
         __salt__["grains.setval"]("bigip_f5_trans", {label: trans_id})
 
-        return "Transaction: {trans_id} - has successfully been stored in the grain: bigip_f5_trans:{label}".format(
-            trans_id=trans_id, label=label
+        return (
+            "Transaction: {trans_id} - has successfully been stored in the grain:"
+            " bigip_f5_trans:{label}".format(trans_id=trans_id, label=label)
         )
     else:
         return data
@@ -308,7 +309,7 @@ def list_transaction(hostname, username, password, label):
     bigip_session = _build_session(username, password)
 
     # pull the trans id from the grain
-    trans_id = __salt__["grains.get"]("bigip_f5_trans:{label}".format(label=label))
+    trans_id = __salt__["grains.get"](f"bigip_f5_trans:{label}")
 
     if trans_id:
 
@@ -316,15 +317,15 @@ def list_transaction(hostname, username, password, label):
         try:
             response = bigip_session.get(
                 BIG_IP_URL_BASE.format(host=hostname)
-                + "/transaction/{trans_id}/commands".format(trans_id=trans_id)
+                + f"/transaction/{trans_id}/commands"
             )
             return _load_response(response)
         except requests.exceptions.ConnectionError as e:
             return _load_connection_error(hostname, e)
     else:
         return (
-            "Error: the label for this transaction was not defined as a grain.  Begin a new transaction using the"
-            " bigip.start_transaction function"
+            "Error: the label for this transaction was not defined as a grain.  Begin a"
+            " new transaction using the bigip.start_transaction function"
         )
 
 
@@ -353,7 +354,7 @@ def commit_transaction(hostname, username, password, label):
     bigip_session = _build_session(username, password)
 
     # pull the trans id from the grain
-    trans_id = __salt__["grains.get"]("bigip_f5_trans:{label}".format(label=label))
+    trans_id = __salt__["grains.get"](f"bigip_f5_trans:{label}")
 
     if trans_id:
 
@@ -363,8 +364,7 @@ def commit_transaction(hostname, username, password, label):
         # patch to REST to get trans id
         try:
             response = bigip_session.patch(
-                BIG_IP_URL_BASE.format(host=hostname)
-                + "/transaction/{trans_id}".format(trans_id=trans_id),
+                BIG_IP_URL_BASE.format(host=hostname) + f"/transaction/{trans_id}",
                 data=salt.utils.json.dumps(payload),
             )
             return _load_response(response)
@@ -372,8 +372,8 @@ def commit_transaction(hostname, username, password, label):
             return _load_connection_error(hostname, e)
     else:
         return (
-            "Error: the label for this transaction was not defined as a grain.  Begin a new transaction using the"
-            " bigip.start_transaction function"
+            "Error: the label for this transaction was not defined as a grain.  Begin a"
+            " new transaction using the bigip.start_transaction function"
         )
 
 
@@ -402,23 +402,22 @@ def delete_transaction(hostname, username, password, label):
     bigip_session = _build_session(username, password)
 
     # pull the trans id from the grain
-    trans_id = __salt__["grains.get"]("bigip_f5_trans:{label}".format(label=label))
+    trans_id = __salt__["grains.get"](f"bigip_f5_trans:{label}")
 
     if trans_id:
 
         # patch to REST to get trans id
         try:
             response = bigip_session.delete(
-                BIG_IP_URL_BASE.format(host=hostname)
-                + "/transaction/{trans_id}".format(trans_id=trans_id)
+                BIG_IP_URL_BASE.format(host=hostname) + f"/transaction/{trans_id}"
             )
             return _load_response(response)
         except requests.exceptions.ConnectionError as e:
             return _load_connection_error(hostname, e)
     else:
         return (
-            "Error: the label for this transaction was not defined as a grain.  Begin a new transaction using the"
-            " bigip.start_transaction function"
+            "Error: the label for this transaction was not defined as a grain.  Begin a"
+            " new transaction using the bigip.start_transaction function"
         )
 
 
@@ -454,8 +453,7 @@ def list_node(hostname, username, password, name=None, trans_label=None):
     try:
         if name:
             response = bigip_session.get(
-                BIG_IP_URL_BASE.format(host=hostname)
-                + "/ltm/node/{name}".format(name=name)
+                BIG_IP_URL_BASE.format(host=hostname) + f"/ltm/node/{name}"
             )
         else:
             response = bigip_session.get(
@@ -590,8 +588,7 @@ def modify_node(
     # put to REST
     try:
         response = bigip_session.put(
-            BIG_IP_URL_BASE.format(host=hostname)
-            + "/ltm/node/{name}".format(name=name),
+            BIG_IP_URL_BASE.format(host=hostname) + f"/ltm/node/{name}",
             data=salt.utils.json.dumps(payload),
         )
     except requests.exceptions.ConnectionError as e:
@@ -629,7 +626,7 @@ def delete_node(hostname, username, password, name, trans_label=None):
     # delete to REST
     try:
         response = bigip_session.delete(
-            BIG_IP_URL_BASE.format(host=hostname) + "/ltm/node/{name}".format(name=name)
+            BIG_IP_URL_BASE.format(host=hostname) + f"/ltm/node/{name}"
         )
     except requests.exceptions.ConnectionError as e:
         return _load_connection_error(hostname, e)
@@ -669,7 +666,7 @@ def list_pool(hostname, username, password, name=None):
         if name:
             response = bigip_session.get(
                 BIG_IP_URL_BASE.format(host=hostname)
-                + "/ltm/pool/{name}/?expandSubcollections=true".format(name=name)
+                + f"/ltm/pool/{name}/?expandSubcollections=true"
             )
         else:
             response = bigip_session.get(
@@ -988,8 +985,7 @@ def modify_pool(
     # post to REST
     try:
         response = bigip_session.put(
-            BIG_IP_URL_BASE.format(host=hostname)
-            + "/ltm/pool/{name}".format(name=name),
+            BIG_IP_URL_BASE.format(host=hostname) + f"/ltm/pool/{name}",
             data=salt.utils.json.dumps(payload),
         )
     except requests.exceptions.ConnectionError as e:
@@ -1024,7 +1020,7 @@ def delete_pool(hostname, username, password, name):
     # delete to REST
     try:
         response = bigip_session.delete(
-            BIG_IP_URL_BASE.format(host=hostname) + "/ltm/pool/{name}".format(name=name)
+            BIG_IP_URL_BASE.format(host=hostname) + f"/ltm/pool/{name}"
         )
     except requests.exceptions.ConnectionError as e:
         return _load_connection_error(hostname, e)
@@ -1095,8 +1091,7 @@ def replace_pool_members(hostname, username, password, name, members):
     # put to REST
     try:
         response = bigip_session.put(
-            BIG_IP_URL_BASE.format(host=hostname)
-            + "/ltm/pool/{name}".format(name=name),
+            BIG_IP_URL_BASE.format(host=hostname) + f"/ltm/pool/{name}",
             data=salt.utils.json.dumps(payload),
         )
     except requests.exceptions.ConnectionError as e:
@@ -1152,8 +1147,7 @@ def add_pool_member(hostname, username, password, name, member):
     # post to REST
     try:
         response = bigip_session.post(
-            BIG_IP_URL_BASE.format(host=hostname)
-            + "/ltm/pool/{name}/members".format(name=name),
+            BIG_IP_URL_BASE.format(host=hostname) + f"/ltm/pool/{name}/members",
             data=salt.utils.json.dumps(payload),
         )
     except requests.exceptions.ConnectionError as e:
@@ -1251,7 +1245,7 @@ def modify_pool_member(
     try:
         response = bigip_session.put(
             BIG_IP_URL_BASE.format(host=hostname)
-            + "/ltm/pool/{name}/members/{member}".format(name=name, member=member),
+            + f"/ltm/pool/{name}/members/{member}",
             data=salt.utils.json.dumps(payload),
         )
     except requests.exceptions.ConnectionError as e:
@@ -1288,8 +1282,7 @@ def delete_pool_member(hostname, username, password, name, member):
     # delete to REST
     try:
         response = bigip_session.delete(
-            BIG_IP_URL_BASE.format(host=hostname)
-            + "/ltm/pool/{name}/members/{member}".format(name=name, member=member)
+            BIG_IP_URL_BASE.format(host=hostname) + f"/ltm/pool/{name}/members/{member}"
         )
     except requests.exceptions.ConnectionError as e:
         return _load_connection_error(hostname, e)
@@ -1329,7 +1322,7 @@ def list_virtual(hostname, username, password, name=None):
         if name:
             response = bigip_session.get(
                 BIG_IP_URL_BASE.format(host=hostname)
-                + "/ltm/virtual/{name}/?expandSubcollections=true".format(name=name)
+                + f"/ltm/virtual/{name}/?expandSubcollections=true"
             )
         else:
             response = bigip_session.get(
@@ -1601,8 +1594,10 @@ def create_virtual(
                 elif vlans["disabled"]:
                     payload["vlans-disabled"] = True
             except Exception:  # pylint: disable=broad-except
-                return "Error: Unable to Parse vlans dictionary: \n\tvlans={vlans}".format(
-                    vlans=vlans
+                return (
+                    "Error: Unable to Parse vlans dictionary: \n\tvlans={vlans}".format(
+                        vlans=vlans
+                    )
                 )
         elif vlans == "none":
             payload["vlans"] = "none"
@@ -1888,8 +1883,10 @@ def modify_virtual(
                 elif vlans["disabled"]:
                     payload["vlans-disabled"] = True
             except Exception:  # pylint: disable=broad-except
-                return "Error: Unable to Parse vlans dictionary: \n\tvlans={vlans}".format(
-                    vlans=vlans
+                return (
+                    "Error: Unable to Parse vlans dictionary: \n\tvlans={vlans}".format(
+                        vlans=vlans
+                    )
                 )
         elif vlans == "none":
             payload["vlans"] = "none"
@@ -1918,8 +1915,7 @@ def modify_virtual(
     # put to REST
     try:
         response = bigip_session.put(
-            BIG_IP_URL_BASE.format(host=hostname)
-            + "/ltm/virtual/{name}".format(name=name),
+            BIG_IP_URL_BASE.format(host=hostname) + f"/ltm/virtual/{name}",
             data=salt.utils.json.dumps(payload),
         )
     except requests.exceptions.ConnectionError as e:
@@ -1954,8 +1950,7 @@ def delete_virtual(hostname, username, password, name):
     # delete to REST
     try:
         response = bigip_session.delete(
-            BIG_IP_URL_BASE.format(host=hostname)
-            + "/ltm/virtual/{name}".format(name=name)
+            BIG_IP_URL_BASE.format(host=hostname) + f"/ltm/virtual/{name}"
         )
     except requests.exceptions.ConnectionError as e:
         return _load_connection_error(hostname, e)
@@ -1967,7 +1962,11 @@ def delete_virtual(hostname, username, password, name):
 
 
 def list_monitor(
-    hostname, username, password, monitor_type, name=None,
+    hostname,
+    username,
+    password,
+    monitor_type,
+    name=None,
 ):
     """
     A function to connect to a bigip device and list an existing monitor.  If no name is provided than all
@@ -2006,8 +2005,7 @@ def list_monitor(
             )
         else:
             response = bigip_session.get(
-                BIG_IP_URL_BASE.format(host=hostname)
-                + "/ltm/monitor/{type}".format(type=monitor_type)
+                BIG_IP_URL_BASE.format(host=hostname) + f"/ltm/monitor/{monitor_type}"
             )
     except requests.exceptions.ConnectionError as e:
         return _load_connection_error(hostname, e)
@@ -2058,8 +2056,7 @@ def create_monitor(hostname, username, password, monitor_type, name, **kwargs):
     # post to REST
     try:
         response = bigip_session.post(
-            BIG_IP_URL_BASE.format(host=hostname)
-            + "/ltm/monitor/{type}".format(type=monitor_type),
+            BIG_IP_URL_BASE.format(host=hostname) + f"/ltm/monitor/{monitor_type}",
             data=salt.utils.json.dumps(payload),
         )
     except requests.exceptions.ConnectionError as e:
@@ -2112,7 +2109,7 @@ def modify_monitor(hostname, username, password, monitor_type, name, **kwargs):
     try:
         response = bigip_session.put(
             BIG_IP_URL_BASE.format(host=hostname)
-            + "/ltm/monitor/{type}/{name}".format(type=monitor_type, name=name),
+            + f"/ltm/monitor/{monitor_type}/{name}",
             data=salt.utils.json.dumps(payload),
         )
     except requests.exceptions.ConnectionError as e:
@@ -2151,7 +2148,7 @@ def delete_monitor(hostname, username, password, monitor_type, name):
     try:
         response = bigip_session.delete(
             BIG_IP_URL_BASE.format(host=hostname)
-            + "/ltm/monitor/{type}/{name}".format(type=monitor_type, name=name)
+            + f"/ltm/monitor/{monitor_type}/{name}"
         )
     except requests.exceptions.ConnectionError as e:
         return _load_connection_error(hostname, e)
@@ -2163,7 +2160,11 @@ def delete_monitor(hostname, username, password, monitor_type, name):
 
 
 def list_profile(
-    hostname, username, password, profile_type, name=None,
+    hostname,
+    username,
+    password,
+    profile_type,
+    name=None,
 ):
     """
     A function to connect to a bigip device and list an existing profile.  If no name is provided than all
@@ -2202,8 +2203,7 @@ def list_profile(
             )
         else:
             response = bigip_session.get(
-                BIG_IP_URL_BASE.format(host=hostname)
-                + "/ltm/profile/{type}".format(type=profile_type)
+                BIG_IP_URL_BASE.format(host=hostname) + f"/ltm/profile/{profile_type}"
             )
     except requests.exceptions.ConnectionError as e:
         return _load_connection_error(hostname, e)
@@ -2287,8 +2287,7 @@ def create_profile(hostname, username, password, profile_type, name, **kwargs):
     # post to REST
     try:
         response = bigip_session.post(
-            BIG_IP_URL_BASE.format(host=hostname)
-            + "/ltm/profile/{type}".format(type=profile_type),
+            BIG_IP_URL_BASE.format(host=hostname) + f"/ltm/profile/{profile_type}",
             data=salt.utils.json.dumps(payload),
         )
     except requests.exceptions.ConnectionError as e:
@@ -2381,7 +2380,7 @@ def modify_profile(hostname, username, password, profile_type, name, **kwargs):
     try:
         response = bigip_session.put(
             BIG_IP_URL_BASE.format(host=hostname)
-            + "/ltm/profile/{type}/{name}".format(type=profile_type, name=name),
+            + f"/ltm/profile/{profile_type}/{name}",
             data=salt.utils.json.dumps(payload),
         )
     except requests.exceptions.ConnectionError as e:
@@ -2420,7 +2419,7 @@ def delete_profile(hostname, username, password, profile_type, name):
     try:
         response = bigip_session.delete(
             BIG_IP_URL_BASE.format(host=hostname)
-            + "/ltm/profile/{type}/{name}".format(type=profile_type, name=name)
+            + f"/ltm/profile/{profile_type}/{name}"
         )
     except requests.exceptions.ConnectionError as e:
         return _load_connection_error(hostname, e)
