@@ -46,6 +46,7 @@ Connection module for Amazon Elasticsearch Service
 :codeauthor: Herbert Buurman <herbert.buurman@ogd.nl>
 :depends: boto3
 """
+
 # keep lint from choking on _get_conn and _cache_id
 # pylint: disable=E0602
 
@@ -369,10 +370,7 @@ def create_elasticsearch_domain(
             ret["result"] = True
             ret["response"] = res["DomainStatus"]
         if blocking:
-            waiter = __utils__["boto3_elasticsearch.get_waiter"](
-                conn, waiter="ESDomainAvailable"
-            )
-            waiter.wait(DomainName=domain_name)
+            conn.get_waiter("ESDomainAvailable").wait(DomainName=domain_name)
     except (ParamValidationError, ClientError, WaiterError) as exp:
         ret.update({"error": __utils__["boto3.get_error"](exp)["message"]})
     return ret
@@ -402,10 +400,7 @@ def delete_elasticsearch_domain(
         conn.delete_elasticsearch_domain(DomainName=domain_name)
         ret["result"] = True
         if blocking:
-            waiter = __utils__["boto3_elasticsearch.get_waiter"](
-                conn, waiter="ESDomainDeleted"
-            )
-            waiter.wait(DomainName=domain_name)
+            conn.get_waiter("ESDomainDeleted").wait(DomainName=domain_name)
     except (ParamValidationError, ClientError, WaiterError) as exp:
         ret.update({"error": __utils__["boto3.get_error"](exp)["message"]})
     return ret
@@ -1209,10 +1204,7 @@ def update_elasticsearch_domain_config(
             ret["result"] = True
             ret["response"] = res["DomainConfig"]
         if blocking:
-            waiter = __utils__["boto3_elasticsearch.get_waiter"](
-                conn, waiter="ESDomainAvailable"
-            )
-            waiter.wait(DomainName=domain_name)
+            conn.get_waiter("ESDomainAvailable").wait(DomainName=domain_name)
     except (ParamValidationError, ClientError, WaiterError) as exp:
         ret.update({"error": __utils__["boto3.get_error"](exp)["message"]})
     return ret
@@ -1275,10 +1267,7 @@ def upgrade_elasticsearch_domain(
             ret["result"] = True
             ret["response"] = res
         if blocking:
-            waiter = __utils__["boto3_elasticsearch.get_waiter"](
-                conn, waiter="ESUpgradeFinished"
-            )
-            waiter.wait(DomainName=domain_name)
+            conn.get_waiter("ESUpgradeFinished").wait(DomainName=domain_name)
     except (ParamValidationError, ClientError, WaiterError) as exp:
         ret.update({"error": __utils__["boto3.get_error"](exp)["message"]})
     return ret
@@ -1324,10 +1313,7 @@ def wait_for_upgrade(domain_name, region=None, keyid=None, key=None, profile=Non
     ret = {"result": False}
     try:
         conn = _get_conn(region=region, keyid=keyid, key=key, profile=profile)
-        waiter = __utils__["boto3_elasticsearch.get_waiter"](
-            conn, waiter="ESUpgradeFinished"
-        )
-        waiter.wait(DomainName=domain_name)
+        conn.get_waiter("ESUpgradeFinished").wait(DomainName=domain_name)
         ret["result"] = True
     except (ParamValidationError, ClientError, WaiterError) as exp:
         ret.update({"error": __utils__["boto3.get_error"](exp)["message"]})
@@ -1383,7 +1369,7 @@ def check_upgrade_eligibility(
     if str(elasticsearch_version) not in compatible_versions:
         ret["result"] = True
         ret["response"] = False
-        ret["error"] = 'Desired version "{}" not in compatible versions: {}.' "".format(
+        ret["error"] = 'Desired version "{}" not in compatible versions: {}.'.format(
             elasticsearch_version, compatible_versions
         )
         return ret
