@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Connection module for Amazon CognitoIdentity
 
@@ -73,21 +72,18 @@ Connection module for Amazon CognitoIdentity
 :depends: boto3
 
 """
+
 # keep lint from choking on _get_conn and _cache_id
 # pylint: disable=E0602
 
-# Import Python libs
-from __future__ import absolute_import, print_function, unicode_literals
 
 import logging
 
-# Import Salt libs
 import salt.utils.compat
 import salt.utils.versions
 
 log = logging.getLogger(__name__)
 
-# Import third party libs
 
 # pylint: disable=import-error
 try:
@@ -118,7 +114,6 @@ def __virtual__():
 
 
 def __init__(opts):
-    salt.utils.compat.pack_dunder(__name__)
     if HAS_BOTO:
         __utils__["boto3.assign_funcs"](__name__, "cognito-identity")
 
@@ -153,7 +148,6 @@ def describe_identity_pools(
     keyid=None,
     profile=None,
 ):
-
     """
     Given an identity pool name, (optionally if an identity pool id is given,
     the given name will be ignored)
@@ -371,7 +365,7 @@ def set_identity_pool_roles(
             if role_arn is None:
                 return {
                     "set": False,
-                    "error": "invalid AuthenticatedRole {0}".format(AuthenticatedRole),
+                    "error": f"invalid AuthenticatedRole {AuthenticatedRole}",
                 }
             AuthenticatedRole = role_arn
 
@@ -380,7 +374,7 @@ def set_identity_pool_roles(
             if role_arn is None:
                 return {
                     "set": False,
-                    "error": "invalid UnauthenticatedRole {0}".format(
+                    "error": "invalid UnauthenticatedRole {}".format(
                         UnauthenticatedRole
                     ),
                 }
@@ -453,9 +447,9 @@ def update_identity_pool(
     if AllowUnauthenticatedIdentities != request_params.get(
         "AllowUnauthenticatedIdentities"
     ):
-        request_params[
-            "AllowUnauthenticatedIdentities"
-        ] = AllowUnauthenticatedIdentities
+        request_params["AllowUnauthenticatedIdentities"] = (
+            AllowUnauthenticatedIdentities
+        )
 
     current_val = request_params.pop("SupportedLoginProviders", None)
     if SupportedLoginProviders is not None and SupportedLoginProviders != current_val:
