@@ -41,15 +41,16 @@ Connection module for Amazon Route53
 
 :depends: boto
 """
+
 # keep lint from choking on _get_conn and _cache_id
 # pylint: disable=E0602
 
 
 import logging
 import time
+from collections import OrderedDict
 
 import salt.utils.compat
-import salt.utils.odict as odict
 import salt.utils.versions
 from salt.exceptions import SaltInvocationError
 
@@ -142,7 +143,7 @@ def describe_hosted_zones(
     conn = _get_conn(region=region, key=key, keyid=keyid, profile=profile)
     if zone_id and domain_name:
         raise SaltInvocationError(
-            "At most one of zone_id or domain_name may " "be provided"
+            "At most one of zone_id or domain_name may be provided"
         )
     retries = 10
     while retries:
@@ -176,8 +177,8 @@ def describe_hosted_zones(
                     log.debug("Throttled by AWS API.")
                 elif "PriorRequestNotComplete" == e.code:
                     log.debug(
-                        "The request was rejected by AWS API.\
-                              Route 53 was still processing a prior request"
+                        "The request was rejected by AWS API. "
+                        "Route 53 was still processing a prior request."
                     )
                 time.sleep(3)
                 retries -= 1
@@ -262,7 +263,7 @@ def zone_exists(
 
         salt myminion boto_route53.zone_exists example.org
 
-   retry_on_errors
+    retry_on_errors
         Continue to query if the zone exists after an error is
         raised. The previously used argument `retry_on_rate_limit`
         was deprecated for this argument. Users can still use
@@ -277,7 +278,6 @@ def zone_exists(
         `rate_limit_retries` to ensure backwards compatibility,
         but please migrate to using the favored `error_retries`
         argument instead.
-
     """
     if region is None:
         region = "universal"
@@ -300,8 +300,8 @@ def zone_exists(
                     log.debug("Throttled by AWS API.")
                 elif "PriorRequestNotComplete" == e.code:
                     log.debug(
-                        "The request was rejected by AWS API.\
-                              Route 53 was still processing a prior request"
+                        "The request was rejected by AWS API. "
+                        "Route 53 was still processing a prior request "
                     )
                 time.sleep(3)
                 error_retries -= 1
@@ -485,8 +485,8 @@ def create_healthcheck(
                     log.debug("Throttled by AWS API.")
                 elif "PriorRequestNotComplete" == exc.code:
                     log.debug(
-                        "The request was rejected by AWS API.\
-                              Route 53 was still processing a prior request"
+                        "The request was rejected by AWS API. "
+                        "Route 53 was still processing a prior request."
                     )
                 time.sleep(3)
                 error_retries -= 1
@@ -554,7 +554,7 @@ def get_record(
 
         salt myminion boto_route53.get_record test.example.org example.org A
 
-   retry_on_errors
+    retry_on_errors
         Continue to query if the zone exists after an error is
         raised. The previously used argument `retry_on_rate_limit`
         was deprecated for this argument. Users can still use
@@ -582,7 +582,7 @@ def get_record(
             error_retries = rate_limit_retries
 
     _record = None
-    ret = odict.OrderedDict()
+    ret = OrderedDict()
     while error_retries > 0:
         try:
             if split_dns:
@@ -590,7 +590,7 @@ def get_record(
             else:
                 _zone = conn.get_zone(zone)
             if not _zone:
-                msg = "Failed to retrieve zone {}".format(zone)
+                msg = f"Failed to retrieve zone {zone}"
                 log.error(msg)
                 return None
             _type = record_type.upper()
@@ -609,8 +609,8 @@ def get_record(
                     log.debug("Throttled by AWS API.")
                 elif "PriorRequestNotComplete" == e.code:
                     log.debug(
-                        "The request was rejected by AWS API.\
-                              Route 53 was still processing a prior request"
+                        "The request was rejected by AWS API. "
+                        "Route 53 was still processing a prior request."
                     )
                 time.sleep(3)
                 error_retries -= 1
@@ -665,7 +665,7 @@ def add_record(
 
         salt myminion boto_route53.add_record test.example.org 1.1.1.1 example.org A
 
-   retry_on_errors
+    retry_on_errors
         Continue to query if the zone exists after an error is
         raised. The previously used argument `retry_on_rate_limit`
         was deprecated for this argument. Users can still use
@@ -699,7 +699,7 @@ def add_record(
             else:
                 _zone = conn.get_zone(zone)
             if not _zone:
-                msg = "Failed to retrieve zone {}".format(zone)
+                msg = f"Failed to retrieve zone {zone}"
                 log.error(msg)
                 return False
             _type = record_type.upper()
@@ -711,8 +711,8 @@ def add_record(
                     log.debug("Throttled by AWS API.")
                 elif "PriorRequestNotComplete" == e.code:
                     log.debug(
-                        "The request was rejected by AWS API.\
-                              Route 53 was still processing a prior request"
+                        "The request was rejected by AWS API. "
+                        "Route 53 was still processing a prior request."
                     )
                 time.sleep(3)
                 error_retries -= 1
@@ -734,8 +734,8 @@ def add_record(
                     log.debug("Throttled by AWS API.")
                 elif "PriorRequestNotComplete" == e.code:
                     log.debug(
-                        "The request was rejected by AWS API.\
-                              Route 53 was still processing a prior request"
+                        "The request was rejected by AWS API. "
+                        "Route 53 was still processing a prior request."
                     )
                 time.sleep(3)
                 error_retries -= 1
@@ -772,7 +772,7 @@ def update_record(
 
         salt myminion boto_route53.modify_record test.example.org 1.1.1.1 example.org A
 
-   retry_on_errors
+    retry_on_errors
         Continue to query if the zone exists after an error is
         raised. The previously used argument `retry_on_rate_limit`
         was deprecated for this argument. Users can still use
@@ -798,7 +798,7 @@ def update_record(
     else:
         _zone = conn.get_zone(zone)
     if not _zone:
-        msg = "Failed to retrieve zone {}".format(zone)
+        msg = f"Failed to retrieve zone {zone}"
         log.error(msg)
         return False
     _type = record_type.upper()
@@ -824,8 +824,8 @@ def update_record(
                     log.debug("Throttled by AWS API.")
                 elif "PriorRequestNotComplete" == e.code:
                     log.debug(
-                        "The request was rejected by AWS API.\
-                              Route 53 was still processing a prior request"
+                        "The request was rejected by AWS API. "
+                        "Route 53 was still processing a prior request."
                     )
                 time.sleep(3)
                 error_retries -= 1
@@ -861,7 +861,7 @@ def delete_record(
 
         salt myminion boto_route53.delete_record test.example.org example.org A
 
-   retry_on_errors
+    retry_on_errors
         Continue to query if the zone exists after an error is
         raised. The previously used argument `retry_on_rate_limit`
         was deprecated for this argument. Users can still use
@@ -887,7 +887,7 @@ def delete_record(
     else:
         _zone = conn.get_zone(zone)
     if not _zone:
-        msg = "Failed to retrieve zone {}".format(zone)
+        msg = f"Failed to retrieve zone {zone}"
         log.error(msg)
         return False
     _type = record_type.upper()
@@ -914,8 +914,8 @@ def delete_record(
                     log.debug("Throttled by AWS API.")
                 elif "PriorRequestNotComplete" == e.code:
                     log.debug(
-                        "The request was rejected by AWS API.\
-                              Route 53 was still processing a prior request"
+                        "The request was rejected by AWS API. "
+                        "Route 53 was still processing a prior request."
                     )
                 time.sleep(3)
                 error_retries -= 1
@@ -1046,7 +1046,7 @@ def create_hosted_zone(
 
     if not domain_name.endswith("."):
         raise SaltInvocationError(
-            "Domain MUST be fully-qualified, complete " "with ending period."
+            "Domain MUST be fully-qualified, complete with ending period."
         )
 
     conn = _get_conn(region=region, key=key, keyid=keyid, profile=profile)
@@ -1066,7 +1066,7 @@ def create_hosted_zone(
     if private_zone:
         if not _exactly_one((vpc_name, vpc_id)):
             raise SaltInvocationError(
-                "Either vpc_name or vpc_id is required " "when creating a private zone."
+                "Either vpc_name or vpc_id is required when creating a private zone."
             )
         vpcs = __salt__["boto_vpc.describe_vpcs"](
             vpc_id=vpc_id,
@@ -1080,7 +1080,7 @@ def create_hosted_zone(
             vpcs = [v for v in vpcs if v["region"] == vpc_region]
         if not vpcs:
             log.error(
-                "Private zone requested but a VPC matching given criteria" " not found."
+                "Private zone requested but a VPC matching given criteria not found."
             )
             return None
         if len(vpcs) > 1:
