@@ -12,11 +12,9 @@ Connection module for Amazon SSM
 
 :depends: boto3
 """
-# Import Python libs
+
 import logging
 
-# Import Salt libs
-import salt.utils.boto3mod
 import salt.utils.json as json
 import salt.utils.versions
 
@@ -29,7 +27,7 @@ def __virtual__():
     """
     has_boto_reqs = salt.utils.versions.check_boto_reqs()
     if has_boto_reqs is True:
-        salt.utils.boto3mod.assign_funcs(__name__, "ssm")
+        __utils__["boto3.assign_funcs"](__name__, "ssm")
     return has_boto_reqs
 
 
