@@ -1,14 +1,10 @@
-# -*- coding: utf-8 -*-
 """
 Use composer to install PHP dependencies for a directory
 """
-from __future__ import absolute_import, print_function, unicode_literals
 
-# Import python libs
 import logging
 import os.path
 
-# Import salt libs
 import salt.utils.args
 import salt.utils.path
 from salt.exceptions import (
@@ -52,7 +48,7 @@ def did_composer_install(dir):
 
         salt '*' composer.did_composer_install /var/www/application
     """
-    lockFile = "{0}/vendor".format(dir)
+    lockFile = f"{dir}/vendor"
     if os.path.exists(lockFile):
         return True
     return False
@@ -140,7 +136,7 @@ def _run_composer(
     # Validate Composer is there
     if not _valid_composer(composer):
         raise CommandNotFoundError(
-            "'composer.{0}' is not available. Couldn't find '{1}'.".format(
+            "'composer.{}' is not available. Couldn't find '{}'.".format(
                 action, composer
             )
         )
@@ -151,7 +147,7 @@ def _run_composer(
     # Don't need a dir for the 'selfupdate' action; all other actions do need a dir
     if directory is None and action != "selfupdate":
         raise SaltInvocationError(
-            "The 'directory' argument is required for composer.{0}".format(action)
+            f"The 'directory' argument is required for composer.{action}"
         )
 
     # Base Settings
