@@ -37,16 +37,13 @@ def _exit_status(retcode, stderr=None):
     """
     Translate exit status of imgadm
     """
-    if retcode == 0:
-        return "Successful completion."
-    if retcode == 1:
-        if stderr:
-            return stderr
-        return "An error occurred."
-    if retcode == 2:
-        return "Usage error."
-    if retcode == 3:
-        return "Image not installed."
+    ret = {
+        0: "Successful completion.",
+        1: "An error occurred." if not stderr else stderr,
+        2: "Usage error.",
+        3: "Image not installed.",
+    }
+    return ret[retcode]
 
 
 def _parse_image_meta(image=None, detail=False):
