@@ -9,11 +9,11 @@ Module for running fmadm and fmdump on Solaris
 """
 
 import logging
+from collections import OrderedDict
 
 import salt.utils.decorators as decorators
 import salt.utils.path
 import salt.utils.platform
-from salt.utils.odict import OrderedDict
 
 log = logging.getLogger(__name__)
 
@@ -69,7 +69,7 @@ def _parse_fmdump(output):
     # parse entries
     for entry in output:
         entry = [item for item in entry.split(" ") if item]
-        entry = ["{} {} {}".format(entry[0], entry[1], entry[2])] + entry[3:]
+        entry = [f"{entry[0]} {entry[1]} {entry[2]}"] + entry[3:]
 
         # prepare faults
         fault = OrderedDict()
@@ -152,7 +152,7 @@ def _fmadm_action_fmri(action, fmri):
     """
     ret = {}
     fmadm = _check_fmadm()
-    cmd = "{cmd} {action} {fmri}".format(cmd=fmadm, action=action, fmri=fmri)
+    cmd = f"{fmadm} {action} {fmri}"
     res = __salt__["cmd.run_all"](cmd)
     retcode = res["retcode"]
     result = {}
@@ -260,8 +260,8 @@ def list_records(after=None, before=None):
     fmdump = _check_fmdump()
     cmd = "{cmd}{after}{before}".format(
         cmd=fmdump,
-        after=" -t {}".format(after) if after else "",
-        before=" -T {}".format(before) if before else "",
+        after=f" -t {after}" if after else "",
+        before=f" -T {before}" if before else "",
     )
     res = __salt__["cmd.run_all"](cmd)
     retcode = res["retcode"]
@@ -289,7 +289,7 @@ def show(uuid):
     """
     ret = {}
     fmdump = _check_fmdump()
-    cmd = "{cmd} -u {uuid} -V".format(cmd=fmdump, uuid=uuid)
+    cmd = f"{fmdump} -u {uuid} -V"
     res = __salt__["cmd.run_all"](cmd)
     retcode = res["retcode"]
     result = {}
@@ -313,7 +313,7 @@ def config():
     """
     ret = {}
     fmadm = _check_fmadm()
-    cmd = "{cmd} config".format(cmd=fmadm)
+    cmd = f"{fmadm} config"
     res = __salt__["cmd.run_all"](cmd)
     retcode = res["retcode"]
     result = {}
@@ -340,7 +340,7 @@ def load(path):
     """
     ret = {}
     fmadm = _check_fmadm()
-    cmd = "{cmd} load {path}".format(cmd=fmadm, path=path)
+    cmd = f"{fmadm} load {path}"
     res = __salt__["cmd.run_all"](cmd)
     retcode = res["retcode"]
     result = {}
@@ -367,7 +367,7 @@ def unload(module):
     """
     ret = {}
     fmadm = _check_fmadm()
-    cmd = "{cmd} unload {module}".format(cmd=fmadm, module=module)
+    cmd = f"{fmadm} unload {module}"
     res = __salt__["cmd.run_all"](cmd)
     retcode = res["retcode"]
     result = {}
@@ -397,7 +397,7 @@ def reset(module, serd=None):
     ret = {}
     fmadm = _check_fmadm()
     cmd = "{cmd} reset {serd}{module}".format(
-        cmd=fmadm, serd="-s {} ".format(serd) if serd else "", module=module
+        cmd=fmadm, serd=f"-s {serd} " if serd else "", module=module
     )
     res = __salt__["cmd.run_all"](cmd)
     retcode = res["retcode"]
