@@ -52,6 +52,21 @@ def _refine_enc(enc):
         "ecdsa-sha2-nistp256",
     ]
     ed25519 = ["ed25519", "ssh-ed25519"]
+    also_allowed = [
+        "rsa-sha2-512",
+        "rsa-sha2-256",
+        "rsa-sha2-512-cert-v01@openssh.com",
+        "rsa-sha2-256-cert-v01@openssh.com",
+        "ssh-rsa-cert-v01@openssh.com",
+        "ecdsa-sha2-nistp256-cert-v01@openssh.com",
+        "ecdsa-sha2-nistp384-cert-v01@openssh.com",
+        "ecdsa-sha2-nistp521-cert-v01@openssh.com",
+        "sk-ecdsa-sha2-nistp256@openssh.com",
+        "sk-ecdsa-sha2-nistp256-cert-v01@openssh.com",
+        "ssh-ed25519-cert-v01@openssh.com",
+        "sk-ssh-ed25519@openssh.com",
+        "sk-ssh-ed25519-cert-v01@openssh.com",
+    ]
 
     if enc in rsa:
         return "ssh-rsa"
@@ -65,8 +80,10 @@ def _refine_enc(enc):
         return enc
     elif enc in ed25519:
         return "ssh-ed25519"
+    elif enc in also_allowed:
+        return enc
     else:
-        raise CommandExecutionError("Incorrect encryption key type '{}'.".format(enc))
+        raise CommandExecutionError(f"Incorrect encryption key type '{enc}'.")
 
 
 def _format_auth_line(key, enc, comment, options):
@@ -76,7 +93,7 @@ def _format_auth_line(key, enc, comment, options):
     line = ""
     if options:
         line += "{} ".format(",".join(options))
-    line += "{} {} {}\n".format(enc, key, comment)
+    line += f"{enc} {key} {comment}\n"
     return line
 
 
@@ -117,7 +134,7 @@ def _get_config_file(user, config):
     """
     uinfo = __salt__["user.info"](user)
     if not uinfo:
-        raise CommandExecutionError("User '{}' does not exist".format(user))
+        raise CommandExecutionError(f"User '{user}' does not exist")
     home = uinfo["home"]
     config = _expand_authorized_keys_path(config, user, home)
     if not os.path.isabs(config):
@@ -152,10 +169,10 @@ def _replace_auth_key(
                     lines.append(line)
                     continue
                 comps = re.findall(
-                    r"((.*)\s)?(ssh-[a-z0-9-]+|ecdsa-[a-z0-9-]+)\s([a-zA-Z0-9+/]+={0,2})(\s(.*))?",
+                    r"((.*)\s)?((?:sk-)?(?:ssh|ecdsa)-[a-z0-9@.-]+)\s([a-zA-Z0-9+/]+={0,2})(\s(.*))?",
                     line,
                 )
-                if len(comps) > 0 and len(comps[0]) > 3 and comps[0][3] == key:
+                if comps and len(comps[0]) > 3 and comps[0][3] == key:
                     # Found our key, replace it
                     lines.append(auth_line)
                 else:
@@ -166,9 +183,7 @@ def _replace_auth_key(
                 # Write out any changes
                 _fh.writelines(salt.utils.data.encode(lines))
     except OSError as exc:
-        raise CommandExecutionError(
-            "Problem reading or writing to key file: {}".format(exc)
-        )
+        raise CommandExecutionError(f"Problem reading or writing to key file: {exc}")
 
 
 def _validate_keys(key_file, fingerprint_hash_type):
@@ -176,7 +191,7 @@ def _validate_keys(key_file, fingerprint_hash_type):
     Return a dict containing validated keys in the passed file
     """
     ret = {}
-    linere = re.compile(r"^(.*?)\s?((?:ssh\-|ecds)[\w-]+\s.+)$")
+    linere = re.compile(r"^(.*?)\s?((?:sk-)?(?:ssh\-|ecds)[\w@.-]+\s.+)$")
 
     try:
         with salt.utils.files.fopen(key_file, "r") as _fh:
@@ -224,7 +239,7 @@ def _validate_keys(key_file, fingerprint_hash_type):
                     "fingerprint": fingerprint,
                 }
     except OSError:
-        raise CommandExecutionError("Problem reading ssh key file {}".format(key_file))
+        raise CommandExecutionError(f"Problem reading ssh key file {key_file}")
 
     return ret
 
@@ -260,7 +275,7 @@ def _fingerprint(public_key, fingerprint_hash_type):
         hash_func = getattr(hashlib, hash_type)
     except AttributeError:
         raise CommandExecutionError(
-            "The fingerprint_hash_type {} is not supported.".format(hash_type)
+            f"The fingerprint_hash_type {hash_type} is not supported."
         )
 
     try:
@@ -288,7 +303,7 @@ def _get_known_hosts_file(config=None, user=None):
             if not uinfo:
                 return {
                     "status": "error",
-                    "error": "User {} does not exist".format(user),
+                    "error": f"User {user} does not exist",
                 }
             full = os.path.join(uinfo["home"], config)
         else:
@@ -326,9 +341,7 @@ def host_keys(keydir=None, private=True, certs=True):
         m = fnre.match(fn_)
         if m:
             if not m.group("pub") and private is False:
-                log.info(
-                    "Skipping private key file %s as " "private is set to False", fn_
-                )
+                log.info("Skipping private key file %s as private is set to False", fn_)
                 continue
             if m.group("cert") and certs is False:
                 log.info("Skipping key file %s as certs is set to False", fn_)
@@ -418,7 +431,7 @@ def check_key_file(
         return {}
     s_keys = _validate_keys(keyfile, fingerprint_hash_type)
     if not s_keys:
-        err = "No keys detected in {}. Is file properly " "formatted?".format(source)
+        err = f"No keys detected in {source}. Is file properly formatted?"
         log.error(err)
         __context__["ssh_auth.error"] = err
         return {}
@@ -511,7 +524,7 @@ def rm_auth_key_from_file(
 
     s_keys = _validate_keys(lfile, fingerprint_hash_type)
     if not s_keys:
-        err = "No keys detected in {}. Is file properly formatted?".format(source)
+        err = f"No keys detected in {source}. Is file properly formatted?"
         log.error(err)
         __context__["ssh_auth.error"] = err
         return "fail"
@@ -546,14 +559,14 @@ def rm_auth_key(user, key, config=".ssh/authorized_keys", fingerprint_hash_type=
     current = auth_keys(
         user, config=config, fingerprint_hash_type=fingerprint_hash_type
     )
-    linere = re.compile(r"^(.*?)\s?((?:ssh\-|ecds)[\w-]+\s.+)$")
+    linere = re.compile(r"^(.*?)\s?((?:sk-)?(?:ssh\-|ecds)[\w@.-]+\s.+)$")
     if key in current:
         # Remove the key
         full = _get_config_file(user, config)
 
         # Return something sensible if the file doesn't exist
         if not os.path.isfile(full):
-            return "Authorized keys file {} not present".format(full)
+            return f"Authorized keys file {full} not present"
 
         lines = []
         try:
@@ -629,7 +642,7 @@ def set_auth_key_from_file(
 
     s_keys = _validate_keys(lfile, fingerprint_hash_type)
     if not s_keys:
-        err = "No keys detected in {}. Is file properly formatted?".format(source)
+        err = f"No keys detected in {source}. Is file properly formatted?"
         log.error(err)
         __context__["ssh_auth.error"] = err
         return "fail"
@@ -776,12 +789,11 @@ def _get_matched_host_line_numbers(lines, enc):
     number of known_hosts entries with encryption key type matching enc,
     one by one.
     """
-    enc = enc if enc else "rsa"
     for i, line in enumerate(lines):
         if i % 2 == 0:
             line_no = int(line.strip().split()[-1])
             line_enc = lines[i + 1].strip().split()[-2]
-            if line_enc != enc:
+            if enc is not None and line_enc != enc:
                 continue
             yield line_no
 
@@ -860,8 +872,8 @@ def recv_known_host_entries(
         The name of the remote host (e.g. "github.com")
 
     enc
-        Defines what type of key is being used, can be ed25519, ecdsa ssh-rsa
-        or ssh-dss
+        Defines what type of key is being used, can be ed25519, ecdsa,
+        ssh-rsa, ssh-dss or any other type as of openssh server version 8.7.
 
     port
         Optional parameter, denoting the port of the remote host on which an
@@ -994,7 +1006,7 @@ def rm_known_host(user=None, hostname=None, config=None, port=None):
     if not os.path.isfile(full):
         return {
             "status": "error",
-            "error": "Known hosts file {} does not exist".format(full),
+            "error": f"Known hosts file {full} does not exist",
         }
 
     ssh_hostname = _hostname_and_port_to_ssh_hostname(hostname, port)
@@ -1047,8 +1059,8 @@ def set_known_host(
         the port 22 is used.
 
     enc
-        Defines what type of key is being used, can be ed25519, ecdsa ssh-rsa
-        or ssh-dss
+        Defines what type of key is being used, can be ed25519, ecdsa,
+        ssh-rsa, ssh-dss or any other type as of openssh server version 8.7.
 
     config
         The location of the authorized keys file relative to the user's home
@@ -1088,8 +1100,10 @@ def set_known_host(
     if port is not None and port != DEFAULT_SSH_PORT and hash_known_hosts:
         return {
             "status": "error",
-            "error": "argument port can not be used in "
-            "conjunction with argument hash_known_hosts",
+            "error": (
+                "argument port can not be used in "
+                "conjunction with argument hash_known_hosts"
+            ),
         }
 
     update_required = False
@@ -1101,7 +1115,11 @@ def set_known_host(
         port=port,
         fingerprint_hash_type=fingerprint_hash_type,
     )
-    stored_keys = [h["key"] for h in stored_host_entries] if stored_host_entries else []
+    stored_keys = (
+        [h["key"] for h in stored_host_entries if enc is None or h["enc"] == enc]
+        if stored_host_entries
+        else []
+    )
     stored_fingerprints = (
         [h["fingerprint"] for h in stored_host_entries] if stored_host_entries else []
     )
@@ -1150,9 +1168,8 @@ def set_known_host(
             }
 
         if check_required:
-            for key in known_keys:
-                if key in stored_keys:
-                    return {"status": "exists", "keys": stored_keys}
+            if set(known_keys) == set(stored_keys):
+                return {"status": "exists", "keys": stored_keys}
 
     full = _get_known_hosts_file(config=config, user=user)
 
@@ -1220,9 +1237,9 @@ def set_known_host(
         os.makedirs(ssh_dir)
     except OSError as exc:
         if exc.args[1] == "Permission denied":
-            log.error("Unable to create directory %s: " "%s", ssh_dir, exc.args[1])
+            log.error("Unable to create directory %s: %s", ssh_dir, exc.args[1])
         elif exc.args[1] == "File exists":
-            log.debug("%s already exists, no need to create " "it", ssh_dir)
+            log.debug("%s already exists, no need to create it", ssh_dir)
     else:
         # set proper ownership/permissions
         if user:
@@ -1235,7 +1252,7 @@ def set_known_host(
             ofile.writelines(salt.utils.data.encode(lines))
     except OSError as exception:
         raise CommandExecutionError(
-            "Couldn't append to known hosts file: '{}'".format(exception)
+            f"Couldn't append to known hosts file: '{exception}'"
         )
 
     if not salt.utils.platform.is_windows():
@@ -1361,7 +1378,7 @@ def hash_known_hosts(user=None, config=None):
     if not os.path.isfile(full):
         return {
             "status": "error",
-            "error": "Known hosts file {} does not exist".format(full),
+            "error": f"Known hosts file {full} does not exist",
         }
     origmode = os.stat(full).st_mode
     cmd = ["ssh-keygen", "-H", "-f", full]
@@ -1379,7 +1396,7 @@ def _hostname_and_port_to_ssh_hostname(hostname, port=DEFAULT_SSH_PORT):
     if not port or port == DEFAULT_SSH_PORT:
         return hostname
     else:
-        return "[{}]:{}".format(hostname, port)
+        return f"[{hostname}]:{port}"
 
 
 def key_is_encrypted(key):
