@@ -399,9 +399,14 @@ def get(path, objectType, user=None):
     Get the ACL of an object. Will filter by user if one is provided.
 
     Args:
-        path: The path to the object
-        objectType: The type of object (FILE, DIRECTORY, REGISTRY)
-        user: A user name to filter by
+
+        path (str): The path to the object
+
+        objectType (str): The type of object (FILE, DIRECTORY, REGISTRY)
+
+        user (:obj:`str`, optional):
+            A username to filter by.
+            Default is ``None``.
 
     Returns (dict): A dictionary containing the ACL
 
@@ -409,7 +414,7 @@ def get(path, objectType, user=None):
 
     .. code-block:: bash
 
-        salt 'minion-id' win_dacl.get c:\temp directory
+        salt 'minion-id' win_dacl.get 'c:\\temp' directory
     """
     ret = {"Path": path, "ACLs": []}
 
@@ -430,20 +435,29 @@ def get(path, objectType, user=None):
 
 def add_ace(path, objectType, user, permission, acetype, propagation):
     r"""
-    add an ace to an object
+    Add an ace to an object
 
-    path:  path to the object (i.e. c:\\temp\\file, HKEY_LOCAL_MACHINE\\SOFTWARE\\KEY, etc)
-    user: user to add
-    permission:  permissions for the user
-    acetype:  either allow/deny for each user/permission (ALLOW, DENY)
-    propagation: how the ACE applies to children for Registry Keys and Directories(KEY, KEY&SUBKEYS, SUBKEYS)
+    Args:
+
+        path (str):
+            Path to the object (i.e. c:\\temp\\file, HKEY_LOCAL_MACHINE\\SOFTWARE\\KEY, etc)
+
+        user (str): User to add
+
+        permission (str): Permissions for the user
+
+        acetype (str): Either allow/deny for each user/permission (ALLOW, DENY)
+
+        propagation (str):
+            How the ACE applies to children for Registry Keys and Directories
+            (KEY, KEY&SUBKEYS, SUBKEYS)
 
     CLI Example:
 
     .. code-block:: bash
 
-        allow domain\fakeuser full control on HKLM\\SOFTWARE\\somekey, propagate to this key and subkeys
-            salt 'myminion' win_dacl.add_ace 'HKEY_LOCAL_MACHINE\\SOFTWARE\\somekey' 'Registry' 'domain\fakeuser' 'FULLCONTROL' 'ALLOW' 'KEY&SUBKEYS'
+        # allow domain\fakeuser full control on HKLM\\SOFTWARE\\somekey, propagate to this key and subkeys
+        salt 'myminion' win_dacl.add_ace 'HKEY_LOCAL_MACHINE\\SOFTWARE\\somekey' 'Registry' 'domain\fakeuser' 'FULLCONTROL' 'ALLOW' 'KEY&SUBKEYS'
     """
     ret = {"result": None, "changes": {}, "comment": ""}
 
@@ -523,20 +537,35 @@ def rm_ace(path, objectType, user, permission=None, acetype=None, propagation=No
     r"""
     remove an ace to an object
 
-    path:  path to the object (i.e. c:\\temp\\file, HKEY_LOCAL_MACHINE\\SOFTWARE\\KEY, etc)
-    user: user to remove
-    permission:  permissions for the user
-    acetypes:  either allow/deny for each user/permission (ALLOW, DENY)
-    propagation: how the ACE applies to children for Registry Keys and Directories(KEY, KEY&SUBKEYS, SUBKEYS)
+    Args:
 
-    If any of the optional parameters are omitted (or set to None) they act as wildcards.
+        path (str):
+            Path to the object (i.e. c:\\temp\\file, HKEY_LOCAL_MACHINE\\SOFTWARE\\KEY, etc)
+
+        user (str): User to remove
+
+        permission (:obj:`str`, optional):
+            Permission for the user.
+            Default is ``None``.
+
+        acetype (:obj:`str`, optional):
+            Either allow/deny for each user/permission (ALLOW, DENY).
+            Default is ``None``.
+
+        propagation (:obj:`str`, optional):
+            How the ACE applies to children for Registry Keys and Directories
+            (KEY, KEY&SUBKEYS, SUBKEYS).
+            Default is ``None``.
+
+    If any of the optional parameters are omitted (or set to None) they act as
+    wildcards.
 
     CLI Example:
 
     .. code-block:: bash
 
-        remove allow domain\fakeuser full control on HKLM\\SOFTWARE\\somekey propagated to this key and subkeys
-            salt 'myminion' win_dacl.rm_ace 'Registry' 'HKEY_LOCAL_MACHINE\\SOFTWARE\\somekey' 'domain\fakeuser' 'FULLCONTROL' 'ALLOW' 'KEY&SUBKEYS'
+        # Remove allow domain\fakeuser full control on HKLM\\SOFTWARE\\somekey propagated to this key and subkeys
+        salt 'myminion' win_dacl.rm_ace 'Registry' 'HKEY_LOCAL_MACHINE\\SOFTWARE\\somekey' 'domain\fakeuser' 'FULLCONTROL' 'ALLOW' 'KEY&SUBKEYS'
     """
     ret = {"result": None, "changes": {}, "comment": ""}
 
@@ -649,18 +678,24 @@ def _ace_to_text(ace, objectType):
 def _set_dacl_inheritance(path, objectType, inheritance=True, copy=True, clear=False):
     """
     helper function to set the inheritance
+
     Args:
 
         path (str): The path to the object
 
         objectType (str): The type of object
 
-        inheritance (bool): True enables inheritance, False disables
+        inheritance (:obj:`bool`, optional):
+            ``True`` enables inheritance, ``False`` disables.
+            Default is ``True``.
 
-        copy (bool): Copy inherited ACEs to the DACL before disabling
-        inheritance
+        copy (:obj:`bool`, optional):
+            Copy inherited ACEs to the DACL before disabling inheritance.
+            Default is ``True``.
 
-        clear (bool): Remove non-inherited ACEs from the DACL
+        clear (:obj:`bool`, optional):
+            Remove non-inherited ACEs from the DACL.
+            Default is ``False``.
     """
     ret = {"result": False, "comment": "", "changes": {}}
 
@@ -738,12 +773,17 @@ def _set_dacl_inheritance(path, objectType, inheritance=True, copy=True, clear=F
 
 def enable_inheritance(path, objectType, clear=False):
     """
-    enable/disable inheritance on an object
+    Enable/disable inheritance on an object
 
     Args:
-        path: The path to the object
-        objectType: The type of object (FILE, DIRECTORY, REGISTRY)
-        clear: True will remove non-Inherited ACEs from the ACL
+
+        path (str): The path to the object
+
+        objectType (str): The type of object (FILE, DIRECTORY, REGISTRY)
+
+        clear (:obj:`bool`, optional):
+            ``True`` will remove non-Inherited ACEs from the ACL.
+            Default is ``False``.
 
     Returns (dict): A dictionary containing the results
 
@@ -751,7 +791,7 @@ def enable_inheritance(path, objectType, clear=False):
 
     .. code-block:: bash
 
-        salt 'minion-id' win_dacl.enable_inheritance c:\temp directory
+        salt 'minion-id' win_dacl.enable_inheritance 'c:\\temp' directory
     """
     dc = daclConstants()
     objectType = dc.getObjectTypeBit(objectType)
@@ -765,9 +805,15 @@ def disable_inheritance(path, objectType, copy=True):
     Disable inheritance on an object
 
     Args:
-        path: The path to the object
-        objectType: The type of object (FILE, DIRECTORY, REGISTRY)
-        copy: True will copy the Inherited ACEs to the DACL before disabling inheritance
+
+        path (str): The path to the object
+
+        objectType (str): The type of object (FILE, DIRECTORY, REGISTRY)
+
+        copy (:obj:`bool`, optional):
+            ``True`` will copy the Inherited ACEs to the DACL before
+            disabling inheritance.
+            Default is ``True``.
 
     Returns (dict): A dictionary containing the results
 
@@ -775,7 +821,7 @@ def disable_inheritance(path, objectType, copy=True):
 
     .. code-block:: bash
 
-        salt 'minion-id' win_dacl.disable_inheritance c:\temp directory
+        salt 'minion-id' win_dacl.disable_inheritance 'c:\\temp' directory
     """
     dc = daclConstants()
     objectType = dc.getObjectTypeBit(objectType)
@@ -789,9 +835,14 @@ def check_inheritance(path, objectType, user=None):
     Check a specified path to verify if inheritance is enabled
 
     Args:
-        path: path of the registry key or file system object to check
-        objectType: The type of object (FILE, DIRECTORY, REGISTRY)
-        user: if provided, will consider only the ACEs for that user
+
+        path (str): path of the registry key or file system object to check
+
+        objectType (str): The type of object (FILE, DIRECTORY, REGISTRY)
+
+        user (:obj:`str`, optional):
+            If provided, will consider only the ACEs for that user.
+            Default is ``None``.
 
     Returns (bool): 'Inheritance' of True/False
 
@@ -799,7 +850,7 @@ def check_inheritance(path, objectType, user=None):
 
     .. code-block:: bash
 
-        salt 'minion-id' win_dacl.check_inheritance c:\temp directory <username>
+        salt 'minion-id' win_dacl.check_inheritance 'c:\\temp' directory <username>
     """
 
     ret = {"result": False, "Inheritance": False, "comment": ""}
@@ -846,13 +897,30 @@ def check_ace(
     Checks a path to verify the ACE (access control entry) specified exists
 
     Args:
-        path:  path to the file/reg key
-        objectType: The type of object (FILE, DIRECTORY, REGISTRY)
-        user:  user that the ACL is for
-        permission:  permission to test for (READ, FULLCONTROL, etc)
-        acetype:  the type of ACE (ALLOW or DENY)
-        propagation:  the propagation type of the ACE (FILES, FOLDERS, KEY, KEY&SUBKEYS, SUBKEYS, etc)
-        exactPermissionMatch:  the ACL must match exactly, IE if READ is specified, the user must have READ exactly and not FULLCONTROL (which also has the READ permission obviously)
+
+        path (str): Path to the file/reg key
+
+        objectType (str): The type of object (FILE, DIRECTORY, REGISTRY)
+
+        user (str): User that the ACL is for
+
+        permission (:obj:`str`, optional):
+            Permission to test for (READ, FULLCONTROL, etc).
+            Default is ``None``.
+
+        acetype (:obj:`str`, optional):
+            The type of ACE (ALLOW or DENY).
+            Default is ``None``.
+
+        propagation (:obj:`str`, optional):
+            The propagation type of the ACE (FILES, FOLDERS, KEY, KEY&SUBKEYS,
+            SUBKEYS, etc).
+            Default is ``None``.
+
+        exactPermissionMatch (:obj:`bool`, optional):
+            The ACL must match exactly, ie: if ``READ`` is specified, the user
+            must have ``READ`` exactly and not ``FULLCONTROL`` (which also has
+            the ``READ`` permission obviously)
 
     Returns (dict): 'Exists' true if the ACE exists, false if it does not
 
@@ -860,7 +928,7 @@ def check_ace(
 
     .. code-block:: bash
 
-        salt 'minion-id' win_dacl.check_ace c:\temp directory <username> fullcontrol
+        salt 'minion-id' win_dacl.check_ace 'c:\\temp' directory <username> fullcontrol
     """
     ret = {"result": False, "Exists": False, "comment": ""}
 
