@@ -1,8 +1,7 @@
 """
 Install features/packages for Windows using DISM, which is useful for minions
-not running server versions of Windows. Some functions are only available on
+not running server versions of Windows. Some functions are only available on
 Windows 10.
-
 """
 
 import logging
@@ -40,7 +39,7 @@ except OSError:
 
 def __virtual__():
     """
-    Only work on Windows
+    Only works on Windows
     """
     if not salt.utils.platform.is_windows():
         return False, "Only available on Windows systems"
@@ -72,19 +71,30 @@ def add_capability(
     Install a capability
 
     Args:
+
         capability (str): The capability to install
-        source (Optional[str]): The optional source of the capability. Default
-            is set by group policy and can be Windows Update.
-        limit_access (Optional[bool]): Prevent DISM from contacting Windows
-            Update for the source package
-        image (Optional[str]): The path to the root directory of an offline
-            Windows image. If `None` is passed, the running operating system is
-            targeted. Default is None.
-        restart (Optional[bool]): Reboot the machine if required by the install
+
+        source (:obj:`str`, optional):
+            The optional source of the capability. Default is set by group
+            policy and can be Windows Update.
+            Default is ``None``.
+
+        limit_access (:obj:`bool`, optional):
+            Prevent DISM from contacting Windows Update for the source package.
+            Default is ``False``.
+
+        image (:obj:`str`, optional):
+            The path to the root directory of an offline Windows image. If
+            ``None`` is passed, the running operating system is targeted.
+            Default is ``None``.
+
+        restart (:obj:`bool`, optional):
+            Reboot the machine if required by the install.
+            Default is ``False``.
 
     Raises:
         NotImplementedError: For all versions of Windows that are not Windows 10
-        and later. Server editions of Windows use ServerManager instead.
+            and later. Server editions of Windows use ServerManager instead.
 
     Returns:
         dict: A dictionary containing the results of the command
@@ -93,7 +103,7 @@ def add_capability(
 
     .. code-block:: bash
 
-        salt '*' dism.add_capability Tools.Graphics.DirectX~~~~0.0.1.0
+        salt '*' dism.add_capability 'Tools.Graphics.DirectX~~~~0.0.1.0'
     """
     if salt.utils.versions.version_cmp(__grains__["osversion"], "10") == -1:
         raise NotImplementedError(
@@ -124,11 +134,17 @@ def remove_capability(capability, image=None, restart=False):
     Uninstall a capability
 
     Args:
+
         capability(str): The capability to be removed
-        image (Optional[str]): The path to the root directory of an offline
-            Windows image. If `None` is passed, the running operating system is
-            targeted. Default is None.
-        restart (Optional[bool]): Reboot the machine if required by the install
+
+        image (:obj:`str`, optional):
+            The path to the root directory of an offline Windows image. If
+            ``None`` is passed, the running operating system is targeted.
+            Default is ``None``.
+
+        restart (:obj:`bool`, optional):
+            Reboot the machine if required by the install.
+            Default is ``False``.
 
     Raises:
         NotImplementedError: For all versions of Windows that are not Windows 10
@@ -141,7 +157,7 @@ def remove_capability(capability, image=None, restart=False):
 
     .. code-block:: bash
 
-        salt '*' dism.remove_capability Tools.Graphics.DirectX~~~~0.0.1.0
+        salt '*' dism.remove_capability 'Tools.Graphics.DirectX~~~~0.0.1.0'
     """
     if salt.utils.versions.version_cmp(__grains__["osversion"], "10") == -1:
         raise NotImplementedError(
@@ -168,9 +184,11 @@ def get_capabilities(image=None):
     List all capabilities on the system
 
     Args:
-        image (Optional[str]): The path to the root directory of an offline
-            Windows image. If `None` is passed, the running operating system is
-            targeted. Default is None.
+
+        image (:obj:`str`, optional):
+            The path to the root directory of an offline Windows image. If
+            ``None`` is passed, the running operating system is targeted.
+            Default is ``None``.
 
     Raises:
         NotImplementedError: For all versions of Windows that are not Windows 10
@@ -211,9 +229,11 @@ def installed_capabilities(image=None):
     List the capabilities installed on the system
 
     Args:
-        image (Optional[str]): The path to the root directory of an offline
-            Windows image. If `None` is passed, the running operating system is
-            targeted. Default is None.
+
+        image (:obj:`str`, optional):
+            The path to the root directory of an offline Windows image. If
+            ``None`` is passed, the running operating system is targeted.
+            Default is ``None``.
 
     Raises:
         NotImplementedError: For all versions of Windows that are not Windows 10
@@ -233,7 +253,12 @@ def installed_capabilities(image=None):
             "`installed_capabilities` is not available on this version of "
             f'Windows: {__grains__["osversion"]}'
         )
-    return _get_components("Capability Identity", "Capabilities", "Installed")
+    return _get_components(
+        type_regex="Capability Identity",
+        plural_type="Capabilities",
+        install_value="Installed",
+        image=image,
+    )
 
 
 def available_capabilities(image=None):
@@ -241,9 +266,11 @@ def available_capabilities(image=None):
     List the capabilities available on the system
 
     Args:
-        image (Optional[str]): The path to the root directory of an offline
-            Windows image. If `None` is passed, the running operating system is
-            targeted. Default is None.
+
+        image (:obj:`str`, optional):
+            The path to the root directory of an offline Windows image. If
+            ``None`` is passed, the running operating system is targeted.
+            Default is ``None``.
 
     Raises:
         NotImplementedError: For all versions of Windows that are not Windows 10
@@ -263,7 +290,12 @@ def available_capabilities(image=None):
             "`installed_capabilities` is not available on this version of "
             f'Windows: {__grains__["osversion"]}'
         )
-    return _get_components("Capability Identity", "Capabilities", "Not Present")
+    return _get_components(
+        type_regex="Capability Identity",
+        plural_type="Capabilities",
+        install_value="Not Present",
+        image=image,
+    )
 
 
 def add_feature(
@@ -279,20 +311,36 @@ def add_feature(
     Install a feature using DISM
 
     Args:
+
         feature (str): The feature to install
-        package (Optional[str]): The parent package for the feature. You do not
-            have to specify the package if it is the Windows Foundation Package.
-            Otherwise, use package to specify the parent package of the feature
-        source (Optional[str]): The optional source of the capability. Default
-            is set by group policy and can be Windows Update
-        limit_access (Optional[bool]): Prevent DISM from contacting Windows
-            Update for the source package
-        enable_parent (Optional[bool]): True will enable all parent features of
-            the specified feature
-        image (Optional[str]): The path to the root directory of an offline
-            Windows image. If `None` is passed, the running operating system is
-            targeted. Default is None.
-        restart (Optional[bool]): Reboot the machine if required by the install
+
+        package (:obj:`str`, optional):
+            The parent package for the feature. You do not have to specify the
+            package if it is the Windows Foundation Package. Otherwise, use
+            package to specify the parent package of the feature.
+            Default is ``None``.
+
+        source (:obj:`str`, optional):
+            The optional source of the capability. Default is set by group
+            policy and can be Windows Update.
+            Default is ``None``.
+
+        limit_access (:obj:`bool`, optional):
+            Prevent DISM from contacting Windows Update for the source package.
+            Default is ``False``.
+
+        enable_parent (:obj:`bool`, optional):
+            ``True`` will enable all parent features of the specified feature.
+            Default is ``False``.
+
+        image (:obj:`str`, optional):
+            The path to the root directory of an offline Windows image. If
+            ``None`` is passed, the running operating system is targeted.
+            Default is ``None``.
+
+        restart (:obj:`bool`, optional):
+            Reboot the machine if required by the install.
+            Default is ``False``.
 
     Returns:
         dict: A dictionary containing the results of the command
@@ -301,7 +349,7 @@ def add_feature(
 
     .. code-block:: bash
 
-        salt '*' dism.add_feature NetFx3
+        salt '*' dism.add_feature 'NetFx3'
     """
     cmd = [
         bin_dism,
@@ -329,13 +377,22 @@ def remove_feature(feature, remove_payload=False, image=None, restart=False):
     Disables the feature.
 
     Args:
-        feature (str): The feature to uninstall
-        remove_payload (Optional[bool]): Remove the feature's payload. Must
-            supply source when enabling in the future.
-        image (Optional[str]): The path to the root directory of an offline
-            Windows image. If `None` is passed, the running operating system is
-            targeted. Default is None.
-        restart (Optional[bool]): Reboot the machine if required by the install
+
+        feature (str): The feature to uninstall.
+
+        remove_payload (:obj:`bool`, optional):
+            Remove the feature's payload. Must supply source when enabling in
+            the future.
+            Default is ``False``.
+
+        image (:obj:`str`, optional):
+            The path to the root directory of an offline Windows image. If
+            ``None`` is passed, the running operating system is targeted.
+            Default is ``None``.
+
+        restart (:obj:`bool`, optional):
+            Reboot the machine if required by the install.
+            Default is ``False``.
 
     Returns:
         dict: A dictionary containing the results of the command
@@ -344,7 +401,7 @@ def remove_feature(feature, remove_payload=False, image=None, restart=False):
 
     .. code-block:: bash
 
-        salt '*' dism.remove_feature NetFx3
+        salt '*' dism.remove_feature 'NetFx3'
     """
     cmd = [
         bin_dism,
@@ -367,16 +424,22 @@ def get_features(package=None, image=None):
     List features on the system or in a package
 
     Args:
-        package (Optional[str]): The full path to the package. Can be either a
-            .cab file or a folder. Should point to the original source of the
-            package, not to where the file is installed. You cannot use this
-            command to get package information for .msu files
+
+        package (:obj:`str`, optional):
+            The full path to the package. Can be either a .cab file or a folder.
+            Should point to the original source of the package, not to where the
+            file is installed. You cannot use this command to get package
+            information for .msu files
 
             This can also be the name of a package as listed in
             ``dism.installed_packages``
-        image (Optional[str]): The path to the root directory of an offline
-            Windows image. If `None` is passed, the running operating system is
-            targeted. Default is None.
+
+            Default is ``None``.
+
+        image (:obj:`str`, optional):
+            The path to the root directory of an offline Windows image. If
+            ``None`` is passed, the running operating system is targeted.
+            Default is ``None``.
 
     Returns:
         list: A list of features
@@ -389,10 +452,10 @@ def get_features(package=None, image=None):
             salt '*' dism.get_features
 
             # Return all features in package.cab
-            salt '*' dism.get_features C:\\packages\\package.cab
+            salt '*' dism.get_features 'C:\\packages\\package.cab'
 
             # Return all features in the calc package
-            salt '*' dism.get_features Microsoft.Windows.Calc.Demo~6595b6144ccf1df~x86~en~1.0.0.0
+            salt '*' dism.get_features 'Microsoft.Windows.Calc.Demo~6595b6144ccf1df~x86~en~1.0.0.0'
     """
     cmd = [
         bin_dism,
@@ -421,9 +484,11 @@ def installed_features(image=None):
     List the features installed on the system
 
     Args:
-        image (Optional[str]): The path to the root directory of an offline
-            Windows image. If `None` is passed, the running operating system is
-            targeted. Default is None.
+
+        image (:obj:`str`, optional):
+            The path to the root directory of an offline Windows image. If
+            ``None`` is passed, the running operating system is targeted.
+            Default is ``None``.
 
     Returns:
         list: A list of installed features
@@ -434,7 +499,12 @@ def installed_features(image=None):
 
         salt '*' dism.installed_features
     """
-    return _get_components("Feature Name", "Features", "Enabled")
+    return _get_components(
+        type_regex="Feature Name",
+        plural_type="Features",
+        install_value="Enabled",
+        image=image,
+    )
 
 
 def available_features(image=None):
@@ -442,9 +512,11 @@ def available_features(image=None):
     List the features available on the system
 
     Args:
-        image (Optional[str]): The path to the root directory of an offline
-            Windows image. If `None` is passed, the running operating system is
-            targeted. Default is None.
+
+        image (:obj:`str`, optional):
+            The path to the root directory of an offline Windows image. If
+            ``None`` is passed, the running operating system is targeted.
+            Default is ``None``.
 
     Returns:
         list: A list of available features
@@ -455,7 +527,12 @@ def available_features(image=None):
 
         salt '*' dism.available_features
     """
-    return _get_components("Feature Name", "Features", "Disabled")
+    return _get_components(
+        type_regex="Feature Name",
+        plural_type="Features",
+        install_value="Disabled",
+        image=image,
+    )
 
 
 def add_package(
@@ -465,27 +542,31 @@ def add_package(
     Install a package using DISM
 
     Args:
+
         package (str):
-            The package to install. Can be a .cab file, a .msu file, or a folder
+            The package to install. Can be a .cab file, a .msu file, or a
+            folder.
 
             .. note::
                 An `.msu` package is supported only when the target image is
                 offline, either mounted or applied.
 
-        ignore_check (Optional[bool]):
-            Skip installation of the package if the applicability checks fail
+        ignore_check (:obj:`bool`, optional):
+            Skip installation of the package if the applicability checks fail.
+            Default is ``False``.
 
-        prevent_pending (Optional[bool]):
+        prevent_pending (:obj:`bool`, optional):
             Skip the installation of the package if there are pending online
-            actions
+            actions. Default is ``False``.
 
-        image (Optional[str]):
+        image (:obj:`str`, optional):
             The path to the root directory of an offline Windows image. If
             ``None`` is passed, the running operating system is targeted.
-            Default is None.
+            Default is ``None``.
 
-        restart (Optional[bool]):
-            Reboot the machine if required by the install
+        restart (:obj:`bool`, optional):
+            Reboot the machine if required by the install.
+            Default is ``False``.
 
     Returns:
         dict: A dictionary containing the results of the command
@@ -494,7 +575,7 @@ def add_package(
 
     .. code-block:: bash
 
-        salt '*' dism.add_package C:\\Packages\\package.cab
+        salt '*' dism.add_package 'C:\\Packages\\package.cab'
     """
     cmd = [
         bin_dism,
@@ -573,15 +654,21 @@ def remove_package(package, image=None, restart=False):
     Uninstall a package
 
     Args:
-        package (str): The full path to the package. Can be either a .cab file
-            or a folder. Should point to the original source of the package, not
-            to where the file is installed. This can also be the name of a
-            package as listed in ``dism.installed_packages``
-        image (Optional[str]): The path to the root directory of an offline
-            Windows image. If `None` is passed, the running operating system is
-            targeted. Default is None.
-        restart (Optional[bool]): Reboot the machine if required by the
-            uninstall
+
+        package (str):
+            The full path to the package. Can be either a .cab file or a folder.
+            Should point to the original source of the package, not to where the
+            file is installed. This can also be the name of a package as listed
+            in ``dism.installed_packages``
+
+        image (:obj:`str`, optional):
+            The path to the root directory of an offline Windows image. If
+            ``None`` is passed, the running operating system is targeted.
+            Default is ``None``.
+
+        restart (:obj:`bool`, optional):
+            Reboot the machine if required by the uninstall.
+            Default is ``False``.
 
     Returns:
         dict: A dictionary containing the results of the command
@@ -591,10 +678,10 @@ def remove_package(package, image=None, restart=False):
     .. code-block:: bash
 
         # Remove the Calc Package
-        salt '*' dism.remove_package Microsoft.Windows.Calc.Demo~6595b6144ccf1df~x86~en~1.0.0.0
+        salt '*' dism.remove_package 'Microsoft.Windows.Calc.Demo~6595b6144ccf1df~x86~en~1.0.0.0'
 
         # Remove the package.cab (does not remove C:\\packages\\package.cab)
-        salt '*' dism.remove_package C:\\packages\\package.cab
+        salt '*' dism.remove_package 'C:\\packages\\package.cab'
     """
     cmd = [
         bin_dism,
@@ -616,15 +703,18 @@ def remove_package(package, image=None, restart=False):
 
 def get_kb_package_name(kb, image=None):
     """
-    Get the actual package name on the system based on the KB name
+    Get the actual package name on the system based on the KB name.
 
     .. versionadded:: 3006.0
 
     Args:
-        kb (str): The name of the KB to remove. Can also be just the KB number
-        image (Optional[str]): The path to the root directory of an offline
-            Windows image. If `None` is passed, the running operating system is
-            targeted. Default is None.
+
+        kb (str): The name of the KB to remove. Can also be just the KB number.
+
+        image (:obj:`str`, optional):
+            The path to the root directory of an offline Windows image. If
+            ``None`` is passed, the running operating system is targeted.
+            Default is ``None``.
 
     Returns:
         str: The name of the package found on the system
@@ -657,12 +747,17 @@ def remove_kb(kb, image=None, restart=False):
     .. versionadded:: 3006.0
 
     Args:
-        kb (str): The name of the KB to remove. Can also be just the KB number
-        image (Optional[str]): The path to the root directory of an offline
-            Windows image. If `None` is passed, the running operating system is
-            targeted. Default is None.
-        restart (Optional[bool]): Reboot the machine if required by the
-            uninstall
+
+        kb (str): The name of the KB to remove. Can also be just the KB number.
+
+        image (:obj:`str`, optional):
+            The path to the root directory of an offline Windows image. If
+            ``None`` is passed, the running operating system is targeted.
+            Default is ``None``.
+
+        restart (:obj:`bool`, optional):
+            Reboot the machine if required by the uninstall. Default is
+            ``False``.
 
     Returns:
         dict: A dictionary containing the results of the command
@@ -690,9 +785,11 @@ def installed_packages(image=None):
     List the packages installed on the system
 
     Args:
-        image (Optional[str]): The path to the root directory of an offline
-            Windows image. If `None` is passed, the running operating system is
-            targeted. Default is None.
+
+        image (:obj:`str`, optional):
+            The path to the root directory of an offline Windows image. If
+            ``None`` is passed, the running operating system is targeted.
+            Default is ``None``.
 
     Returns:
         list: A list of installed packages
@@ -744,13 +841,17 @@ def package_info(package, image=None):
     Display information about a package
 
     Args:
-        package (str): The full path to the package. Can be either a .cab file
-            or a folder. Should point to the original source of the package, not
-            to where the file is installed. You cannot use this command to get
-            package information for .msu files
-        image (Optional[str]): The path to the root directory of an offline
-            Windows image. If `None` is passed, the running operating system is
-            targeted. Default is None.
+
+        package (str):
+            The full path to the package. Can be either a .cab file or a folder.
+            Should point to the original source of the package, not to where the
+            file is installed. You cannot use this command to get package
+            information for .msu files
+
+        image (:obj:`str`, optional):
+            The path to the root directory of an offline Windows image. If
+            ``None`` is passed, the running operating system is targeted.
+            Default is ``None``.
 
     Returns:
         dict: A dictionary containing the results of the command
@@ -759,7 +860,7 @@ def package_info(package, image=None):
 
     .. code-block:: bash
 
-        salt '*' dism.package_info C:\\packages\\package.cab
+        salt '*' dism. package_info 'C:\\packages\\package.cab'
     """
     cmd = [
         bin_dism,
