@@ -82,14 +82,15 @@ def read_reg_pol(policy_class="Machine"):
     human-readable dictionary.
 
     Args:
-        policy_class (str): The registry class to retrieve. Can be one of the
-            following:
+
+        policy_class (:obj:`str`, optional):
+            The registry class to retrieve. Can be one of the following:
 
             - Computer
             - Machine
             - User
 
-            Default is ``Machine``
+            Default is ``Machine``.
 
     Raises:
         SaltInvocationError: Invalid policy class
@@ -127,14 +128,14 @@ def write_reg_pol(data, policy_class="Machine"):
     Args:
         data (dict): A dictionary containing Registry.pol data
 
-        policy_class (str): The registry class to write to. Can be one of the
-            following:
+        policy_class (:obj:`str`, optional):
+            The registry class to write to. Can be one of the following:
 
             - Computer
             - Machine
             - User
 
-            Default is ``Machine``
+            Default is ``Machine``.
 
     Raises:
         SaltInvocationError: Invalid policy class
@@ -181,8 +182,14 @@ def get_value(key, v_name, policy_class="Machine"):
 
         v_name (str): The value name to retrieve
 
-        policy_class (str): The registry class to read from. Can be one of the
-            following:
+        policy_class (:obj:`str`, optional):
+            The registry class to read from. Can be one of the following:
+
+            - Computer
+            - Machine
+            - User
+
+            Default is ``Machine``.
 
     Raises:
         SaltInvocationError: Invalid policy class
@@ -212,7 +219,7 @@ def get_value(key, v_name, policy_class="Machine"):
         if key.lower() == p_key.lower():
             found_key = p_key
             for p_name in pol_data[p_key]:
-                if v_name.lower() in p_name.lower():
+                if v_name.lower() in p_name.lower().split("."):
                     found_name = p_name
 
     if found_key:
@@ -231,8 +238,14 @@ def get_key(key, policy_class="Machine"):
     Args:
         key (str): The registry key where the values reside
 
-        policy_class (str): The registry class to read from. Can be one of the
-            following:
+        policy_class (:obj:`str`, optional):
+            The registry class to read from. Can be one of the following:
+
+            - Computer
+            - Machine
+            - User
+
+            Default is ``Machine``.
 
     Raises:
         SaltInvocationError: Invalid policy class
@@ -284,7 +297,8 @@ def set_value(
 
         v_data(str): The registry value
 
-        v_type (str): The registry value type. Must be one of the following:
+        v_type (:obj:`str`, optional):
+            The registry value type. Must be one of the following:
 
             - REG_BINARY
             - REG_DWORD
@@ -293,16 +307,16 @@ def set_value(
             - REG_QWORD
             - REG_SZ
 
-            Default is REG_DWORD
+            Default is REG_DWORD.
 
-        policy_class (str): The registry class to write to. Can be one of the
-            following:
+        policy_class (:obj:`str`, optional):
+            The registry class to write to. Can be one of the following:
 
             - Computer
             - Machine
             - User
 
-            Default is ``Machine``
+            Default is ``Machine``.
 
     Raises:
         SaltInvocationError: Invalid policy_class
@@ -310,7 +324,7 @@ def set_value(
         SaltInvocationError: v_data doesn't match v_type
 
     Returns:
-        bool: ``True`` if successful, otherwise ``False``
+        bool: ``True`` if successful, otherwise ``False``.
 
     CLI Example:
 
@@ -391,15 +405,20 @@ def set_value(
         log.error("LGPO_REG Mod: Failed to write registry.pol file")
         success = False
 
-    if not salt.utils.win_reg.set_value(
-        hive=hive,
-        key=key,
-        vname=v_name,
-        vdata=v_data,
-        vtype=v_type,
-    ):
-        log.error("LGPO_REG Mod: Failed to set registry entry")
-        success = False
+    # We only want to modify the actual registry value if this is machine policy
+    # The user policy will be applied by the user registry.pol when the user
+    # logs in. Setting it here only sets it on the user running the salt minion,
+    # most likely SYSTEM, which doesn't make sense here
+    if policy_class == "Machine":
+        if not salt.utils.win_reg.set_value(
+            hive=hive,
+            key=key,
+            vname=v_name,
+            vdata=v_data,
+            vtype=v_type,
+        ):
+            log.error("LGPO_REG Mod: Failed to set registry entry")
+            success = False
 
     return success
 
@@ -415,14 +434,14 @@ def disable_value(key, v_name, policy_class="machine"):
 
         v_name (str): The registry value name within the key
 
-        policy_class (str): The registry class to write to. Can be one of the
-            following:
+        policy_class (:obj:`str`, optional):
+            The registry class to write to. Can be one of the following:
 
             - Computer
             - Machine
             - User
 
-            Default is ``Machine``
+            Default is ``Machine``.
 
     Raises:
         SaltInvocationError: Invalid policy_class
@@ -486,13 +505,18 @@ def disable_value(key, v_name, policy_class="machine"):
         log.error("LGPO_REG Mod: Failed to write registry.pol file")
         success = False
 
-    ret = salt.utils.win_reg.delete_value(hive=hive, key=key, vname=v_name)
-    if not ret:
-        if ret is None:
-            log.debug("LGPO_REG Mod: Registry key/value already missing")
-        else:
-            log.error("LGPO_REG Mod: Failed to remove registry entry")
-            success = False
+    # We only want to modify the actual registry value if this is machine policy
+    # The user policy will be applied by the user registry.pol when the user
+    # logs in. Setting it here only sets it on the user running the salt minion,
+    # most likely SYSTEM, which doesn't make sense here
+    if policy_class == "Machine":
+        ret = salt.utils.win_reg.delete_value(hive=hive, key=key, vname=v_name)
+        if not ret:
+            if ret is None:
+                log.debug("LGPO_REG Mod: Registry key/value already missing")
+            else:
+                log.error("LGPO_REG Mod: Failed to remove registry entry")
+                success = False
 
     return success
 
@@ -508,14 +532,14 @@ def delete_value(key, v_name, policy_class="Machine"):
 
         v_name (str): The registry value name within the key
 
-        policy_class (str): The registry class to write to. Can be one of the
-            following:
+        policy_class (:obj:`str`, optional):
+            The registry class to write to. Can be one of the following:
 
             - Computer
             - Machine
             - User
 
-            Default is ``Machine``
+            Default is ``Machine``.
 
     Raises:
         SaltInvocationError: Invalid policy_class
@@ -573,13 +597,18 @@ def delete_value(key, v_name, policy_class="Machine"):
         log.error("LGPO_REG Mod: Failed to write registry.pol file")
         success = False
 
-    ret = salt.utils.win_reg.delete_value(hive=hive, key=key, vname=v_name)
-    if not ret:
-        if ret is None:
-            log.debug("LGPO_REG Mod: Registry key/value already missing")
-        else:
-            log.error("LGPO_REG Mod: Failed to remove registry entry")
-            success = False
+    # We only want to modify the actual registry value if this is machine policy
+    # The user policy will be applied by the user registry.pol when the user
+    # logs in. Setting it here only sets it on the user running the salt minion,
+    # most likely SYSTEM, which doesn't make sense here
+    if policy_class == "Machine":
+        ret = salt.utils.win_reg.delete_value(hive=hive, key=key, vname=v_name)
+        if not ret:
+            if ret is None:
+                log.debug("LGPO_REG Mod: Registry key/value already missing")
+            else:
+                log.error("LGPO_REG Mod: Failed to remove registry entry")
+                success = False
 
     return success
 
