@@ -23,7 +23,7 @@ import salt.utils.json
 import salt.utils.platform
 import salt.utils.powershell
 import salt.utils.versions
-from salt.exceptions import SaltInvocationError
+from salt.exceptions import CommandExecutionError, SaltInvocationError
 
 _DEFAULT_CONTEXT = "LocalMachine"
 _DEFAULT_FORMAT = "cer"
@@ -73,15 +73,19 @@ def _cmd_run(cmd, as_json=False):
         "".join(cmd_full), shell="powershell", python_shell=True
     )
 
-    if cmd_ret["retcode"] != 0:
-        _LOG.error("Unable to execute command: %s\nError: %s", cmd, cmd_ret["stderr"])
+    if cmd_ret["stderr"]:
+        raise CommandExecutionError(
+            "Unable to execute command: {}\nError: {}".format(cmd, cmd_ret["stderr"])
+        )
 
     if as_json:
         try:
             items = salt.utils.json.loads(cmd_ret["stdout"], strict=False)
             return items
         except ValueError:
-            _LOG.error("Unable to parse return data as Json.")
+            raise CommandExecutionError(
+                "Unable to parse return data as JSON:\n{}".format(cmd_ret["stdout"])
+            )
 
     return cmd_ret["stdout"]
 
@@ -90,10 +94,10 @@ def _validate_cert_path(name):
     """
     Ensure that the certificate path, as determind from user input, is valid.
     """
-    cmd = r"Test-Path -Path '{}'".format(name)
+    cmd = rf"Test-Path -Path '{name}'"
 
     if not ast.literal_eval(_cmd_run(cmd=cmd)):
-        raise SaltInvocationError(r"Invalid path specified: {}".format(name))
+        raise SaltInvocationError(rf"Invalid path specified: {name}")
 
 
 def _validate_cert_format(name):
@@ -124,7 +128,7 @@ def get_stores():
         salt '*' win_pki.get_stores
     """
     ret = dict()
-    cmd = r"Get-ChildItem -Path 'Cert:\' | " r"Select-Object LocationName, StoreNames"
+    cmd = r"Get-ChildItem -Path 'Cert:\' | Select-Object LocationName, StoreNames"
 
     items = _cmd_run(cmd=cmd, as_json=True)
 
@@ -140,11 +144,20 @@ def get_certs(context=_DEFAULT_CONTEXT, store=_DEFAULT_STORE):
     """
     Get the available certificates in the given store.
 
-    :param str context: The name of the certificate store location context.
-    :param str store: The name of the certificate store.
+    Args:
 
-    :return: A dictionary of the certificate thumbprints and properties.
-    :rtype: dict
+        context (:obj:`str`, optional):
+            The name of the certificate store location context.
+
+            Default is "LocalMachine"
+
+        store (:obj:`str`, optional):
+            The name of the certificate store.
+
+            Default is "My"
+
+    Returns:
+        dict: A dictionary of the certificate thumbprints and properties.
 
     CLI Example:
 
@@ -155,11 +168,11 @@ def get_certs(context=_DEFAULT_CONTEXT, store=_DEFAULT_STORE):
     ret = dict()
     cmd = list()
     blacklist_keys = ["DnsNameList"]
-    store_path = r"Cert:\{}\{}".format(context, store)
+    store_path = rf"Cert:\{context}\{store}"
 
     _validate_cert_path(name=store_path)
 
-    cmd.append(r"Get-ChildItem -Path '{}' | Select-Object".format(store_path))
+    cmd.append(rf"Get-ChildItem -Path '{store_path}' | Select-Object")
     cmd.append(" DnsNameList, SerialNumber, Subject, Thumbprint, Version")
 
     items = _cmd_run(cmd="".join(cmd), as_json=True)
@@ -183,15 +196,26 @@ def get_cert_file(name, cert_format=_DEFAULT_FORMAT, password=""):
     """
     Get the details of the certificate file.
 
-    :param str name: The filesystem path of the certificate file.
-    :param str cert_format: The certificate format. Specify 'cer' for X.509, or
-        'pfx' for PKCS #12.
-    :param str password: The password of the certificate. Only applicable to pfx
-        format. Note that if used interactively, the password will be seen by all minions.
-        To protect the password, use a state and get the password from pillar.
+    Args:
 
-    :return: A dictionary of the certificate thumbprints and properties.
-    :rtype: dict
+        name (str): The filesystem path of the certificate file.
+
+        cert_format (:obj:`str`, optional):
+            The certificate format. Specify 'cer' for X.509, or 'pfx' for PKCS
+            #12.
+
+            Default is "cer"
+
+        password (:obj:`str`, optional):
+            The password of the certificate. Only applicable to pfx format. Note
+            that if used interactively, the password will be seen by all
+            minions. To protect the password, use a state and get the password
+            from pillar.
+
+            Default is "".
+
+    Returns:
+        dict: A dictionary of the certificate thumbprints and properties.
 
     CLI Example:
 
@@ -216,15 +240,15 @@ def get_cert_file(name, cert_format=_DEFAULT_FORMAT, password=""):
             cmd.append(
                 " System.Security.Cryptography.X509Certificates.X509Certificate2;"
             )
-            cmd.append(r" $CertObject.Import('{}'".format(name))
-            cmd.append(",'{}'".format(password))
+            cmd.append(rf" $CertObject.Import('{name}'")
+            cmd.append(f",'{password}'")
             cmd.append(",'DefaultKeySet') ; $CertObject")
             cmd.append(
                 " | Select-Object DnsNameList, SerialNumber, Subject, "
                 "Thumbprint, Version"
             )
         else:
-            cmd.append(r"Get-PfxCertificate -FilePath '{}'".format(name))
+            cmd.append(rf"Get-PfxCertificate -FilePath '{name}'")
             cmd.append(
                 " | Select-Object DnsNameList, SerialNumber, Subject, "
                 "Thumbprint, Version"
@@ -232,7 +256,7 @@ def get_cert_file(name, cert_format=_DEFAULT_FORMAT, password=""):
     else:
         cmd.append("$CertObject = New-Object")
         cmd.append(" System.Security.Cryptography.X509Certificates.X509Certificate2;")
-        cmd.append(r" $CertObject.Import('{}'); $CertObject".format(name))
+        cmd.append(rf" $CertObject.Import('{name}'); $CertObject")
         cmd.append(
             " | Select-Object DnsNameList, SerialNumber, Subject, Thumbprint, Version"
         )
@@ -265,20 +289,44 @@ def import_cert(
     """
     Import the certificate file into the given certificate store.
 
-    :param str name: The path of the certificate file to import.
-    :param str cert_format: The certificate format. Specify 'cer' for X.509, or
-        'pfx' for PKCS #12.
-    :param str context: The name of the certificate store location context.
-    :param str store: The name of the certificate store.
-    :param bool exportable: Mark the certificate as exportable. Only applicable
-        to pfx format.
-    :param str password: The password of the certificate. Only applicable to pfx
-        format. Note that if used interactively, the password will be seen by all minions.
-        To protect the password, use a state and get the password from pillar.
-    :param str saltenv: The environment the file resides in.
+    Args:
 
-    :return: A boolean representing whether all changes succeeded.
-    :rtype: bool
+        name (str): The path of the certificate file to import.
+
+        cert_format (:obj:`str`, optional):
+            The certificate format. Specify 'cer' for X.509, or 'pfx' for PKCS
+            #12.
+
+            Default is "cer"
+
+        context (:obj:`str`, optional):
+            The name of the certificate store location context.
+
+            Default is "LocalMachine"
+
+        store (str): The name of the certificate store.
+
+            Default is "My"
+
+        exportable (:obj:`bool`, optional):
+            Mark the certificate as exportable. Only applicable to pfx format.
+
+            Default is ``True``.
+
+        password (:obj:`str`, optional):
+            The password of the certificate. Only applicable to pfx format. Note
+            that if used interactively, the password will be seen by all
+            minions. To protect the password, use a state and get the password
+            from pillar.
+
+            Default is "".
+
+        saltenv (:obj:`str`, optional): The environment the file resides in.
+
+            Default is "base".
+
+    Returns:
+        bool: A boolean representing whether all changes succeeded.
 
     CLI Example:
 
@@ -288,7 +336,7 @@ def import_cert(
     """
     cmd = list()
     thumbprint = None
-    store_path = r"Cert:\{}\{}".format(context, store)
+    store_path = rf"Cert:\{context}\{store}"
     cert_format = cert_format.lower()
 
     _validate_cert_format(name=cert_format)
@@ -331,14 +379,14 @@ def import_cert(
         cmd.append(
             r"Import-PfxCertificate " r"-FilePath '{}'".format(cached_source_path)
         )
-        cmd.append(r" -CertStoreLocation '{}'".format(store_path))
+        cmd.append(rf" -CertStoreLocation '{store_path}'")
         cmd.append(r" -Password $Password")
 
         if exportable:
             cmd.append(" -Exportable")
     else:
         cmd.append(r"Import-Certificate " r"-FilePath '{}'".format(cached_source_path))
-        cmd.append(r" -CertStoreLocation '{}'".format(store_path))
+        cmd.append(rf" -CertStoreLocation '{store_path}'")
 
     _cmd_run(cmd="".join(cmd))
 
@@ -366,18 +414,38 @@ def export_cert(
     """
     Export the certificate to a file from the given certificate store.
 
-    :param str name: The destination path for the exported certificate file.
-    :param str thumbprint: The thumbprint value of the target certificate.
-    :param str cert_format: The certificate format. Specify 'cer' for X.509, or
-        'pfx' for PKCS #12.
-    :param str context: The name of the certificate store location context.
-    :param str store: The name of the certificate store.
-    :param str password: The password of the certificate. Only applicable to pfx
-        format. Note that if used interactively, the password will be seen by all minions.
-        To protect the password, use a state and get the password from pillar.
+    Args:
 
-    :return: A boolean representing whether all changes succeeded.
-    :rtype: bool
+        name (str): The destination path for the exported certificate file.
+
+        thumbprint (str): The thumbprint value of the target certificate.
+
+        cert_format (:obj:`str`, optional):
+            The certificate format. Specify 'cer' for X.509, or 'pfx' for PKCS
+            #12.
+
+            Default is "cer"
+
+        context (:obj:`str`, optional):
+            The name of the certificate store location context.
+
+            Default is "LocalMachine"
+
+        store (:obj:`str`, optional):
+            The name of the certificate store.
+
+            Default is "My"
+
+        password (:obj:`str`, optional):
+            The password of the certificate. Only applicable to pfx format. Note
+            that if used interactively, the password will be seen by all
+            minions. To protect the password, use a state and get the password
+            from pillar.
+
+            Default is "".
+
+    Returns:
+        bool: A boolean representing whether all changes succeeded.
 
     CLI Example:
 
@@ -387,7 +455,7 @@ def export_cert(
     """
     cmd = list()
     thumbprint = thumbprint.upper()
-    cert_path = r"Cert:\{}\{}\{}".format(context, store, thumbprint)
+    cert_path = rf"Cert:\{context}\{store}\{thumbprint}"
     cert_format = cert_format.lower()
 
     _validate_cert_path(name=cert_path)
@@ -415,7 +483,7 @@ def export_cert(
             r"Export-Certificate " r"-Cert '{}' -FilePath '{}'".format(cert_path, name)
         )
 
-    cmd.append(r" | Out-Null; Test-Path -Path '{}'".format(name))
+    cmd.append(rf" | Out-Null; Test-Path -Path '{name}'")
 
     ret = ast.literal_eval(_cmd_run(cmd="".join(cmd)))
 
@@ -437,18 +505,39 @@ def test_cert(
     """
     Check the certificate for validity.
 
-    :param str thumbprint: The thumbprint value of the target certificate.
-    :param str context: The name of the certificate store location context.
-    :param str store: The name of the certificate store.
-    :param bool untrusted_root: Whether the root certificate is required to be
-        trusted in chain building.
-    :param str dns_name: The DNS name to verify as valid for the certificate.
-    :param str eku: The enhanced key usage object identifiers to verify for the
-        certificate chain.
+    Args:
 
-    :return: A boolean representing whether the certificate was considered
-        valid.
-    :rtype: bool
+        thumbprint (str): The thumbprint value of the target certificate.
+
+        context (:obj:`str`, optional):
+            The name of the certificate store location context.
+
+            Default is "LocalMachine"
+
+        store (:obj:`str`, optional): The name of the certificate store.
+
+            Default is "My"
+
+        untrusted_root (:obj:`bool`, optional):
+            Whether the root certificate is required to be trusted in chain
+            building.
+
+            Default is ``False``.
+
+        dns_name (:obj:`str`, optional):
+            The DNS name to verify as valid for the certificate.
+
+            Default is "".
+
+        eku (:obj:`str`, optional):
+            The enhanced key usage object identifiers to verify for the
+            certificate chain.
+
+            Default is "".
+
+    Returns:
+        bool: A boolean representing whether the certificate was considered
+            valid.
 
     CLI Example:
 
@@ -458,17 +547,17 @@ def test_cert(
     """
     cmd = list()
     thumbprint = thumbprint.upper()
-    cert_path = r"Cert:\{}\{}\{}".format(context, store, thumbprint)
-    cmd.append(r"Test-Certificate -Cert '{}'".format(cert_path))
+    cert_path = rf"Cert:\{context}\{store}\{thumbprint}"
+    cmd.append(rf"Test-Certificate -Cert '{cert_path}'")
 
     _validate_cert_path(name=cert_path)
 
     if untrusted_root:
         cmd.append(" -AllowUntrustedRoot")
     if dns_name:
-        cmd.append(" -DnsName '{}'".format(dns_name))
+        cmd.append(f" -DnsName '{dns_name}'")
     if eku:
-        cmd.append(" -EKU '{}'".format(eku))
+        cmd.append(f" -EKU '{eku}'")
 
     cmd.append(" -ErrorAction SilentlyContinue")
 
@@ -479,12 +568,21 @@ def remove_cert(thumbprint, context=_DEFAULT_CONTEXT, store=_DEFAULT_STORE):
     """
     Remove the certificate from the given certificate store.
 
-    :param str thumbprint: The thumbprint value of the target certificate.
-    :param str context: The name of the certificate store location context.
-    :param str store: The name of the certificate store.
+    Args:
 
-    :return: A boolean representing whether all changes succeeded.
-    :rtype: bool
+        thumbprint (str): The thumbprint value of the target certificate.
+
+        context (:obj:`str`, optional):
+            The name of the certificate store location context.
+
+            Default is "LocalMachine".
+
+        store (:obj:`str`, optional): The name of the certificate store.
+
+            Default is "My"
+
+    Returns:
+        bool: A boolean representing whether all changes succeeded.
 
     CLI Example:
 
@@ -493,9 +591,9 @@ def remove_cert(thumbprint, context=_DEFAULT_CONTEXT, store=_DEFAULT_STORE):
         salt '*' win_pki.remove_cert thumbprint='AAA000'
     """
     thumbprint = thumbprint.upper()
-    store_path = r"Cert:\{}\{}".format(context, store)
-    cert_path = r"{}\{}".format(store_path, thumbprint)
-    cmd = r"Remove-Item -Path '{}'".format(cert_path)
+    store_path = rf"Cert:\{context}\{store}"
+    cert_path = rf"{store_path}\{thumbprint}"
+    cmd = rf"Remove-Item -Path '{cert_path}'"
 
     current_certs = get_certs(context=context, store=store)
 
