@@ -14,13 +14,13 @@ Module for running ZFS command
 """
 
 import logging
+from collections import OrderedDict
 
 import salt.modules.cmdmod
 import salt.utils.args
 import salt.utils.path
 import salt.utils.platform
 import salt.utils.versions
-from salt.utils.odict import OrderedDict
 
 __virtualname__ = "zfs"
 log = logging.getLogger(__name__)
