@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 """
 Decrypt pillar data through the builtin GPG renderer
 
@@ -17,8 +15,6 @@ Set ``gpg_keydir`` in your config to adjust the homedir the renderer uses.
 
 """
 
-from __future__ import absolute_import, print_function, unicode_literals
-
 import salt.loader
 
 
