@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Read pillar data from a Redis backend
 =====================================
@@ -30,10 +29,7 @@ Configuring the Redis ext_pillar
           - redis: {function: key_value}
 
 """
-# Import Python libs
-from __future__ import absolute_import, print_function, unicode_literals
 
-# Import Salt libs
 import salt.utils.json
 
 __virtualname__ = "redis"
