@@ -65,14 +65,17 @@ def _checksum_file_path(path):
         if re.match(r"..[/\\]", relpath):
             # path is a local file
             relpath = salt.utils.path.join(
-                "local", os.path.splitdrive(path)[-1].lstrip("/\\"),
+                "local",
+                os.path.splitdrive(path)[-1].lstrip("/\\"),
             )
     except ValueError as exc:
         # The path is on a different drive (Windows)
         if str(exc).startswith("path is on"):
             drive, path = os.path.splitdrive(path)
             relpath = salt.utils.path.join(
-                "local", drive.rstrip(":"), path.lstrip("/\\"),
+                "local",
+                drive.rstrip(":"),
+                path.lstrip("/\\"),
             )
         elif str(exc).startswith("Cannot mix UNC"):
             relpath = salt.utils.path.join("unc", path)
@@ -111,12 +114,12 @@ def _update_checksum(path):
                         line[1] = hsum
                     fp_.write("{}:{}\n".format(*line))
                 if hash_type not in [x[0] for x in lines]:
-                    fp_.write("{}:{}\n".format(hash_type, hsum))
+                    fp_.write(f"{hash_type}:{hsum}\n")
         except OSError as exc:
             log.warning(
                 "Failed to update checksum for %s: %s",
                 path,
-                exc.__str__(),
+                exc,
                 exc_info=True,
             )
 
@@ -162,6 +165,52 @@ def _cleanup_destdir(name):
         pass
 
 
+def _check_sig(
+    on_file,
+    signature,
+    signed_by_any=None,
+    signed_by_all=None,
+    keyring=None,
+    gnupghome=None,
+):
+    try:
+        verify = __salt__["gpg.verify"]
+    except KeyError:
+        raise CommandExecutionError(
+            "Signature verification requires the gpg module, "
+            "which could not be found. Make sure you have the "
+            "necessary tools and libraries intalled (gpg, python-gnupg)"
+        )
+    sig = None
+    if signature is not None:
+        # fetch detached signature
+        sig = __salt__["cp.cache_file"](signature, __env__)
+        if not sig:
+            raise CommandExecutionError(
+                f"Detached signature file {signature} not found"
+            )
+
+    res = verify(
+        filename=on_file,
+        signature=sig,
+        keyring=keyring,
+        gnupghome=gnupghome,
+        signed_by_any=signed_by_any,
+        signed_by_all=signed_by_all,
+    )
+
+    if res["res"] is True:
+        return
+    # Ensure detached signature and file are deleted from cache
+    # on signature verification failure.
+    if sig:
+        salt.utils.files.safe_rm(sig)
+    salt.utils.files.safe_rm(on_file)
+    raise CommandExecutionError(
+        f"The file's signature could not be verified: {res['message']}"
+    )
+
+
 def extracted(
     name,
     source,
@@ -186,11 +235,18 @@ def extracted(
     enforce_toplevel=True,
     enforce_ownership_on=None,
     archive_format=None,
-    **kwargs
+    use_etag=False,
+    signature=None,
+    source_hash_sig=None,
+    signed_by_any=None,
+    signed_by_all=None,
+    keyring=None,
+    gnupghome=None,
+    **kwargs,
 ):
     """
     .. versionadded:: 2014.1.0
-    .. versionchanged:: 2016.11.0
+    .. versionchanged:: 2016.11.0,3005
         This state has been rewritten. Some arguments are new to this release
         and will not be available in the 2016.3 release cycle (and earlier).
         Additionally, the **ZIP Archive Handling** section below applies
@@ -658,6 +714,73 @@ def extracted(
     .. _zipfile: https://docs.python.org/2/library/zipfile.html
     .. _xz: http://tukaani.org/xz/
 
+    use_etag
+        If ``True``, remote http/https file sources will attempt to use the
+        ETag header to determine if the remote file needs to be downloaded.
+        This provides a lightweight mechanism for promptly refreshing files
+        changed on a web server without requiring a full hash comparison via
+        the ``source_hash`` parameter.
+
+        .. versionadded:: 3005
+
+    signature
+        Ensure a valid GPG signature exists on the selected ``source`` file.
+        This needs to be a file URI retrievable by
+        `:py:func:`cp.cache_file <salt.modules.cp.cache_file>` which
+        identifies a detached signature.
+
+        .. note::
+
+            A signature is only enforced directly after caching the file,
+            before it is extracted to its final destination. Existing files
+            at the target will never be modified.
+
+            It will be enforced regardless of source type.
+
+        .. versionadded:: 3007.0
+
+    source_hash_sig
+        When ``source`` is a remote file source, ``source_hash`` is a file,
+        ``skip_verify`` is not true and ``use_etag`` is not true, ensure a
+        valid GPG signature exists on the source hash file.
+        Set this to ``true`` for an inline (clearsigned) signature, or to a
+        file URI retrievable by `:py:func:`cp.cache_file <salt.modules.cp.cache_file>`
+        for a detached one.
+
+        .. note::
+
+            A signature on the ``source_hash`` file is enforced regardless of
+            changes since its contents are used to check if an existing file
+            is in the correct state - but only for remote sources!
+            As for ``signature``, existing target files will not be modified,
+            only the cached source_hash and source_hash_sig files will be removed.
+
+        .. versionadded:: 3007.0
+
+    signed_by_any
+        When verifying signatures either on the managed file or its source hash file,
+        require at least one valid signature from one of a list of key fingerprints.
+        This is passed to :py:func:`gpg.verify <salt.modules.gpg.verify>`.
+
+        .. versionadded:: 3007.0
+
+    signed_by_all
+        When verifying signatures either on the managed file or its source hash file,
+        require a valid signature from each of the key fingerprints in this list.
+        This is passed to :py:func:`gpg.verify <salt.modules.gpg.verify>`.
+
+        .. versionadded:: 3007.0
+
+    keyring
+        When verifying signatures, use this keyring.
+
+        .. versionadded:: 3007.0
+
+    gnupghome
+        When verifying signatures, use this GnuPG home.
+
+        .. versionadded:: 3007.0
+
     **Examples**
 
     1. tar with lmza (i.e. xz) compression:
@@ -704,8 +827,7 @@ def extracted(
 
     if skip_files_list_verify and skip_verify:
         ret["comment"] = (
-            'Only one of "skip_files_list_verify" and '
-            '"skip_verify" can be set to True'
+            'Only one of "skip_files_list_verify" and "skip_verify" can be set to True'
         )
         return ret
 
@@ -725,7 +847,7 @@ def extracted(
         keep_source = True
 
     if not _path_is_abs(name):
-        ret["comment"] = "{} is not an absolute path".format(name)
+        ret["comment"] = f"{name} is not an absolute path"
         return ret
     else:
         if not name:
@@ -743,7 +865,7 @@ def extracted(
         # False
         name = name.rstrip(os.sep)
         if os.path.isfile(name):
-            ret["comment"] = "{} exists and is not a directory".format(name)
+            ret["comment"] = f"{name} exists and is not a directory"
             return ret
         # Add back the slash so that file.makedirs properly creates the
         # destdir if it needs to be created. file.makedirs expects a trailing
@@ -753,7 +875,7 @@ def extracted(
         ret["comment"] = "Value for 'if_missing' is not an absolute path"
         return ret
     if not _path_is_abs(enforce_ownership_on):
-        ret["comment"] = "Value for 'enforce_ownership_on' is not an " "absolute path"
+        ret["comment"] = "Value for 'enforce_ownership_on' is not an absolute path"
         return ret
     else:
         if enforce_ownership_on is not None:
@@ -768,27 +890,27 @@ def extracted(
                 # from making this state blow up with a traceback.
                 not_rel = True
             if not_rel:
-                ret[
-                    "comment"
-                ] = "Value for 'enforce_ownership_on' must be within {}".format(name)
+                ret["comment"] = (
+                    f"Value for 'enforce_ownership_on' must be within {name}"
+                )
                 return ret
 
     if if_missing is not None and os.path.exists(if_missing):
         ret["result"] = True
-        ret["comment"] = "Path {} exists".format(if_missing)
+        ret["comment"] = f"Path {if_missing} exists"
         return ret
 
     if user or group:
         if salt.utils.platform.is_windows():
-            ret[
-                "comment"
-            ] = "User/group ownership cannot be enforced on Windows minions"
+            ret["comment"] = (
+                "User/group ownership cannot be enforced on Windows minions"
+            )
             return ret
 
         if user:
             uid = __salt__["file.user_to_uid"](user)
             if uid == "":
-                ret["comment"] = "User {} does not exist".format(user)
+                ret["comment"] = f"User {user} does not exist"
                 return ret
         else:
             uid = -1
@@ -796,7 +918,7 @@ def extracted(
         if group:
             gid = __salt__["file.group_to_gid"](group)
             if gid == "":
-                ret["comment"] = "Group {} does not exist".format(group)
+                ret["comment"] = f"Group {group} does not exist"
                 return ret
         else:
             gid = -1
@@ -812,6 +934,16 @@ def extracted(
             "'source_hash' is not also specified."
         )
 
+    if signature or source_hash_sig:
+        # Fail early in case the gpg module is not present
+        try:
+            __salt__["gpg.verify"]
+        except KeyError:
+            ret["comment"] = (
+                "Cannot verify signatures because the gpg module was not loaded"
+            )
+            return ret
+
     try:
         source_match = __salt__["file.source_list"](source, source_hash, __env__)[0]
     except CommandExecutionError as exc:
@@ -821,7 +953,7 @@ def extracted(
 
     if not source_match:
         ret["result"] = False
-        ret["comment"] = 'Invalid source "{}"'.format(source)
+        ret["comment"] = f'Invalid source "{source}"'
         return ret
 
     urlparsed_source = urlparse(source_match)
@@ -867,7 +999,8 @@ def extracted(
             "Invalid archive_format '{}'. Either set it to a supported "
             "value ({}) or remove this argument and the archive format will "
             "be guessed based on file extension.".format(
-                archive_format, ", ".join(valid_archive_formats),
+                archive_format,
+                ", ".join(valid_archive_formats),
             )
         )
         return ret
@@ -928,9 +1061,9 @@ def extracted(
                 )
     else:
         if password:
-            ret[
-                "comment"
-            ] = "The 'password' argument is only supported for zip archives"
+            ret["comment"] = (
+                "The 'password' argument is only supported for zip archives"
+            )
             return ret
 
     if archive_format == "rar":
@@ -959,7 +1092,7 @@ def extracted(
                 trim_output = int(trim_output)
             except TypeError:
                 ret["comment"] = (
-                    "Invalid value for trim_output, must be True/False or an " "integer"
+                    "Invalid value for trim_output, must be True/False or an integer"
                 )
                 return ret
 
@@ -970,6 +1103,11 @@ def extracted(
                 source_hash=source_hash,
                 source_hash_name=source_hash_name,
                 saltenv=__env__,
+                source_hash_sig=source_hash_sig,
+                signed_by_any=signed_by_any,
+                signed_by_all=signed_by_all,
+                keyring=keyring,
+                gnupghome=gnupghome,
             )
         except CommandExecutionError as exc:
             ret["comment"] = exc.strerror
@@ -1035,10 +1173,10 @@ def extracted(
             # salt/states/file.py from being processed through the loader. If
             # that is the case, we have much more important problems as _all_
             # file states would be unavailable.
-            ret[
-                "comment"
-            ] = "Unable to cache {}, file.cached state not available".format(
-                salt.utils.url.redact_http_basic_auth(source_match)
+            ret["comment"] = (
+                "Unable to cache {}, file.cached state not available".format(
+                    salt.utils.url.redact_http_basic_auth(source_match)
+                )
             )
             return ret
 
@@ -1049,10 +1187,16 @@ def extracted(
                 source_hash_name=source_hash_name,
                 skip_verify=skip_verify,
                 saltenv=__env__,
+                use_etag=use_etag,
+                source_hash_sig=source_hash_sig,
+                signed_by_any=signed_by_any,
+                signed_by_all=signed_by_all,
+                keyring=keyring,
+                gnupghome=gnupghome,
             )
         except Exception as exc:  # pylint: disable=broad-except
             msg = "Failed to cache {}: {}".format(
-                salt.utils.url.redact_http_basic_auth(source_match), exc.__str__()
+                salt.utils.url.redact_http_basic_auth(source_match), exc
             )
             log.exception(msg)
             ret["comment"] = msg
@@ -1070,6 +1214,20 @@ def extracted(
             )
             return result
 
+    if signature:
+        try:
+            _check_sig(
+                cached,
+                signature,
+                signed_by_any=signed_by_any,
+                signed_by_all=signed_by_all,
+                keyring=keyring,
+                gnupghome=gnupghome,
+            )
+        except CommandExecutionError as err:
+            ret["comment"] = f"Failed verifying the source file's signature: {err}"
+            return ret
+
     existing_cached_source_sum = _read_cached_checksum(cached)
 
     if source_hash and source_hash_update and not skip_verify:
@@ -1082,7 +1240,7 @@ def extracted(
         # implicitly enabled by setting the "options" argument.
         try:
             encrypted_zip = __salt__["archive.is_encrypted"](
-                cached, clean=False, saltenv=__env__
+                cached, clean=False, saltenv=__env__, use_etag=use_etag
             )
         except CommandExecutionError:
             # This would happen if archive_format=zip and the source archive is
@@ -1106,6 +1264,7 @@ def extracted(
             strip_components=strip_components,
             clean=False,
             verbose=True,
+            use_etag=use_etag,
         )
     except CommandExecutionError as exc:
         contents = None
@@ -1114,7 +1273,7 @@ def extracted(
             errors.append("'if_missing' must be set")
         if not enforce_ownership_on and (user or group):
             errors.append(
-                "Ownership cannot be managed without setting " "'enforce_ownership_on'."
+                "Ownership cannot be managed without setting 'enforce_ownership_on'."
             )
         msg = exc.strerror
         if errors:
@@ -1131,15 +1290,14 @@ def extracted(
                 )
             else:
                 msg += (
-                    "The following workarounds must be used for this state to "
-                    "proceed"
+                    "The following workarounds must be used for this state to proceed"
                 )
             msg += " (assuming the source file is a valid {} archive):\n".format(
                 archive_format
             )
 
             for error in errors:
-                msg += "\n- {}".format(error)
+                msg += f"\n- {error}"
         ret["comment"] = msg
         return ret
 
@@ -1158,7 +1316,9 @@ def extracted(
             "top-level directory by adding it to the 'name' "
             "value (for example, setting 'name' to {} "
             "instead of {}).".format(
-                archive_format, os.path.join(name, "some_dir"), name,
+                archive_format,
+                os.path.join(name, "some_dir"),
+                name,
             )
         )
         return ret
@@ -1192,7 +1352,7 @@ def extracted(
                 else:
                     ret["comment"] = (
                         "Failed to check for existence of if_missing path "
-                        "({}): {}".format(if_missing, exc.__str__())
+                        "({}): {}".format(if_missing, exc)
                     )
                     return ret
         else:
@@ -1221,13 +1381,11 @@ def extracted(
                             # that dir will raise an ENOTDIR OSError. So we
                             # expect these and will only abort here if the
                             # error code is something else.
-                            ret["comment"] = exc.__str__()
+                            ret["comment"] = str(exc)
                             return ret
 
             if incorrect_type:
-                incorrect_paths = "\n\n" + "\n".join(
-                    ["- {}".format(x) for x in incorrect_type]
-                )
+                incorrect_paths = "\n\n" + "\n".join([f"- {x}" for x in incorrect_type])
                 ret["comment"] = (
                     "The below paths (relative to {}) exist, but are the "
                     "incorrect type (file instead of directory, symlink "
@@ -1272,7 +1430,7 @@ def extracted(
                                 extraction_needed = True
                             except OSError as exc:
                                 if exc.errno != errno.ENOENT:
-                                    errors.append(exc.__str__())
+                                    errors.append(str(exc))
                         if errors:
                             msg = (
                                 "One or more paths existed by were the incorrect "
@@ -1281,7 +1439,7 @@ def extracted(
                                 "following errors were observed:\n"
                             )
                             for error in errors:
-                                msg += "\n- {}".format(error)
+                                msg += f"\n- {error}"
                             ret["comment"] = msg
                             return ret
 
@@ -1327,7 +1485,7 @@ def extracted(
                 salt.utils.files.rm_rf(name.rstrip(os.sep))
                 ret["changes"].setdefault(
                     "removed",
-                    "Directory {} was removed prior to the extraction".format(name),
+                    f"Directory {name} was removed prior to the extraction",
                 )
             except OSError as exc:
                 if exc.errno != errno.ENOENT:
@@ -1338,7 +1496,7 @@ def extracted(
                     "errors were observed:\n".format(name)
                 )
                 for error in errors:
-                    msg += "\n- {}".format(error)
+                    msg += f"\n- {error}"
                 ret["comment"] = msg
                 return ret
 
@@ -1353,7 +1511,7 @@ def extracted(
                     ret["changes"].setdefault("removed", []).append(full_path)
                 except OSError as exc:
                     if exc.errno != errno.ENOENT:
-                        errors.append(exc.__str__())
+                        errors.append(str(exc))
 
             if errors:
                 msg = (
@@ -1361,7 +1519,7 @@ def extracted(
                     "errors were observed:\n"
                 )
                 for error in errors:
-                    msg += "\n- {}".format(error)
+                    msg += f"\n- {error}"
                 ret["comment"] = msg
                 return ret
 
@@ -1380,7 +1538,7 @@ def extracted(
                             options=options,
                             trim_output=trim_output,
                             password=password,
-                            **kwargs
+                            **kwargs,
                         )
                     except (CommandExecutionError, CommandNotFoundError) as exc:
                         ret["comment"] = exc.strerror
@@ -1393,7 +1551,7 @@ def extracted(
                         trim_output=trim_output,
                         password=password,
                         extract_perms=extract_perms,
-                        **kwargs
+                        **kwargs,
                     )
             elif archive_format == "rar":
                 try:
@@ -1407,7 +1565,7 @@ def extracted(
                 if options is None:
                     try:
                         with closing(tarfile.open(cached, "r")) as tar:
-                            tar.extractall(salt.utils.stringutils.to_str(name))
+                            tar.extractall(salt.utils.stringutils.to_str(name))  # nosec
                             files = tar.getnames()
                             if trim_output:
                                 files = files[:trim_output]
@@ -1628,7 +1786,8 @@ def extracted(
                 ret["changes"]["directories_created"] = [name]
             ret["changes"]["extracted_files"] = files
             ret["comment"] = "{} extracted to {}".format(
-                salt.utils.url.redact_http_basic_auth(source_match), name,
+                salt.utils.url.redact_http_basic_auth(source_match),
+                name,
             )
             _add_explanation(ret, source_hash_trigger, contents_missing)
             ret["comment"] += ". Output was trimmed to {} number of lines".format(
@@ -1644,15 +1803,15 @@ def extracted(
     else:
         ret["result"] = True
         if if_missing_path_exists:
-            ret["comment"] = "{} exists".format(if_missing)
+            ret["comment"] = f"{if_missing} exists"
         else:
             ret["comment"] = "All files in archive are already present"
         if __opts__["test"]:
             if ret["changes"].get("updated ownership"):
                 ret["result"] = None
-                ret["comment"] += (
-                    ". Ownership would be updated on one or more " "files/directories."
-                )
+                ret[
+                    "comment"
+                ] += ". Ownership would be updated on one or more files/directories."
 
     if enforce_missing:
         if not if_missing:
@@ -1669,7 +1828,7 @@ def extracted(
             "paths were missing:\n"
         )
         for item in enforce_missing:
-            ret["comment"] += "\n- {}".format(item)
+            ret["comment"] += f"\n- {item}"
 
     if enforce_failed:
         ret["result"] = False
@@ -1678,7 +1837,7 @@ def extracted(
             "unable to change ownership on the following paths:\n"
         )
         for item in enforce_failed:
-            ret["comment"] += "\n- {}".format(item)
+            ret["comment"] += f"\n- {item}"
 
     if not source_is_local:
         if keep_source:
