@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Manage Data Pipelines
 
@@ -49,18 +48,12 @@ config:
           myDDBTableName: my-dynamo-table
 """
 
-# Import Python libs
-from __future__ import absolute_import, print_function, unicode_literals
-
 import copy
 import datetime
 import difflib
 
-# Import Salt lobs
 import salt.utils.data
 import salt.utils.json
-from salt.ext import six
-from salt.ext.six.moves import zip
 
 
 def __virtual__():
@@ -139,22 +132,25 @@ def present(
         profile=profile,
     )
     if present:
-        ret["comment"] = "AWS data pipeline {0} present".format(name)
+        ret["comment"] = f"AWS data pipeline {name} present"
         return ret
 
     if __opts__["test"]:
-        ret["comment"] = "Data pipeline {0} is set to be created or updated".format(
-            name
-        )
+        ret["comment"] = f"Data pipeline {name} is set to be created or updated"
         ret["result"] = None
         return ret
 
     result_create_pipeline = __salt__["boto_datapipeline.create_pipeline"](
-        name, name, region=region, key=key, keyid=keyid, profile=profile,
+        name,
+        name,
+        region=region,
+        key=key,
+        keyid=keyid,
+        profile=profile,
     )
     if "error" in result_create_pipeline:
         ret["result"] = False
-        ret["comment"] = "Failed to create data pipeline {0}: {1}".format(
+        ret["comment"] = "Failed to create data pipeline {}: {}".format(
             name, result_create_pipeline["error"]
         )
         return ret
@@ -179,21 +175,30 @@ def present(
         if _immutable_fields_error(result_pipeline_definition):
             # If update not possible, delete and retry
             result_delete_pipeline = __salt__["boto_datapipeline.delete_pipeline"](
-                pipeline_id, region=region, key=key, keyid=keyid, profile=profile,
+                pipeline_id,
+                region=region,
+                key=key,
+                keyid=keyid,
+                profile=profile,
             )
             if "error" in result_delete_pipeline:
                 ret["result"] = False
-                ret["comment"] = "Failed to delete data pipeline {0}: {1}".format(
+                ret["comment"] = "Failed to delete data pipeline {}: {}".format(
                     pipeline_id, result_delete_pipeline["error"]
                 )
                 return ret
 
             result_create_pipeline = __salt__["boto_datapipeline.create_pipeline"](
-                name, name, region=region, key=key, keyid=keyid, profile=profile,
+                name,
+                name,
+                region=region,
+                key=key,
+                keyid=keyid,
+                profile=profile,
             )
             if "error" in result_create_pipeline:
                 ret["result"] = False
-                ret["comment"] = "Failed to create data pipeline {0}: {1}".format(
+                ret["comment"] = "Failed to create data pipeline {}: {}".format(
                     name, result_create_pipeline["error"]
                 )
                 return ret
@@ -220,17 +225,21 @@ def present(
         if "error" in result_pipeline_definition:
             # Still erroring after possible retry
             ret["result"] = False
-            ret["comment"] = "Failed to create data pipeline {0}: {1}".format(
+            ret["comment"] = "Failed to create data pipeline {}: {}".format(
                 name, result_pipeline_definition["error"]
             )
             return ret
 
     result_activate_pipeline = __salt__["boto_datapipeline.activate_pipeline"](
-        pipeline_id, region=region, key=key, keyid=keyid, profile=profile,
+        pipeline_id,
+        region=region,
+        key=key,
+        keyid=keyid,
+        profile=profile,
     )
     if "error" in result_activate_pipeline:
         ret["result"] = False
-        ret["comment"] = "Failed to create data pipeline {0}: {1}".format(
+        ret["comment"] = "Failed to create data pipeline {}: {}".format(
             name, result_pipeline_definition["error"]
         )
         return ret
@@ -250,10 +259,10 @@ def present(
 
     if not old_pipeline_definition:
         ret["changes"]["new"] = "Pipeline created."
-        ret["comment"] = "Data pipeline {0} created".format(name)
+        ret["comment"] = f"Data pipeline {name} created"
     else:
         ret["changes"]["diff"] = _diff(old_pipeline_definition, new_pipeline_definition)
-        ret["comment"] = "Data pipeline {0} updated".format(name)
+        ret["comment"] = f"Data pipeline {name} updated"
 
     return ret
 
@@ -311,7 +320,11 @@ def _pipeline_present_with_definition(
         that contains a dict with region, key and keyid.
     """
     result_pipeline_id = __salt__["boto_datapipeline.pipeline_id_from_name"](
-        name, region=region, key=key, keyid=keyid, profile=profile,
+        name,
+        region=region,
+        key=key,
+        keyid=keyid,
+        profile=profile,
     )
     if "error" in result_pipeline_id:
         return False, {}
@@ -419,7 +432,7 @@ def _diff(old_pipeline_definition, new_pipeline_definition):
             salt.utils.json.dumps(new_pipeline_definition, indent=4).splitlines(True),
         )
     )
-    return "".join(diff)  # future lint: disable=blacklisted-function
+    return "".join(diff)
 
 
 def _standardize(structure):
@@ -438,7 +451,7 @@ def _standardize(structure):
                 mutating_helper(each)
         elif isinstance(structure, dict):
             structure = dict(structure)
-            for k, v in six.iteritems(structure):
+            for k, v in structure.items():
                 mutating_helper(k)
                 mutating_helper(v)
 
@@ -508,7 +521,7 @@ def _dict_to_list_ids(objects):
     while still satisfying the boto api.
     """
     list_with_ids = []
-    for key, value in six.iteritems(objects):
+    for key, value in objects.items():
         element = {"id": key}
         element.update(value)
         list_with_ids.append(element)
@@ -542,7 +555,7 @@ def _properties_from_dict(d, key_name="key"):
         ]
     """
     fields = []
-    for key, value in six.iteritems(d):
+    for key, value in d.items():
         if isinstance(value, dict):
             fields.append({key_name: key, "refValue": value["ref"]})
         else:
@@ -573,21 +586,29 @@ def absent(name, region=None, key=None, keyid=None, profile=None):
     ret = {"name": name, "result": True, "comment": "", "changes": {}}
 
     result_pipeline_id = __salt__["boto_datapipeline.pipeline_id_from_name"](
-        name, region=region, key=key, keyid=keyid, profile=profile,
+        name,
+        region=region,
+        key=key,
+        keyid=keyid,
+        profile=profile,
     )
     if "error" not in result_pipeline_id:
         pipeline_id = result_pipeline_id["result"]
         if __opts__["test"]:
-            ret["comment"] = "Data pipeline {0} set to be deleted.".format(name)
+            ret["comment"] = f"Data pipeline {name} set to be deleted."
             ret["result"] = None
             return ret
         else:
             __salt__["boto_datapipeline.delete_pipeline"](
-                pipeline_id, region=region, key=key, keyid=keyid, profile=profile,
+                pipeline_id,
+                region=region,
+                key=key,
+                keyid=keyid,
+                profile=profile,
             )
             ret["changes"]["old"] = {"pipeline_id": pipeline_id}
             ret["changes"]["new"] = None
     else:
-        ret["comment"] = "AWS data pipeline {0} absent.".format(name)
+        ret["comment"] = f"AWS data pipeline {name} absent."
 
     return ret
