@@ -120,16 +120,12 @@ def installed(
 
     # Package installed
     else:
-        version_info = __salt__["chocolatey.version"](
-            name=name, check_remote=True, source=source
-        )
-
         full_name = name
-        for pkg in version_info:
+        for pkg in pre_install.keys():
             if name.lower() == pkg.lower():
                 full_name = pkg
 
-        installed_version = version_info[full_name].get("installed")[0]
+        installed_version = pre_install[full_name]
 
         if version:
             if salt.utils.versions.compare(
