@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Management of MySQL grants (user permissions)
 =============================================
@@ -45,7 +44,6 @@ instructions.
        - database: somedb.sometable
        - user: joe
 """
-from __future__ import absolute_import, print_function, unicode_literals
 
 import sys
 
@@ -79,7 +77,7 @@ def present(
     escape=True,
     revoke_first=False,
     ssl_option=False,
-    **connection_args
+    **connection_args,
 ):
     """
     Ensure that the grant is present with the specified properties
@@ -184,14 +182,14 @@ def present(
                     host=host,
                     grant_option=grant_option,
                     escape=escape,
-                    **connection_args
+                    **connection_args,
                 )
 
     # The grant is not present, make it!
     if __opts__["test"]:
         # there is probably better things to make in test mode
         ret["result"] = None
-        ret["comment"] = ("MySQL grant {0} is set to be created").format(name)
+        ret["comment"] = f"MySQL grant {name} is set to be created"
         return ret
     if __salt__["mysql.grant_add"](
         grant, database, user, host, grant_option, escape, ssl_option, **connection_args
@@ -204,7 +202,7 @@ def present(
         ret["comment"] = ret["comment"].format(grant, database, user, host)
         err = _get_mysql_error()
         if err is not None:
-            ret["comment"] += " ({0})".format(err)
+            ret["comment"] += f" ({err})"
         ret["result"] = False
     return ret
 
@@ -217,7 +215,7 @@ def absent(
     host="localhost",
     grant_option=False,
     escape=True,
-    **connection_args
+    **connection_args,
 ):
     """
     Ensure that the grant is absent
@@ -246,12 +244,12 @@ def absent(
 
         if __opts__["test"]:
             ret["result"] = None
-            ret["comment"] = "MySQL grant {0} is set to be " "revoked".format(name)
+            ret["comment"] = f"MySQL grant {name} is set to be revoked"
             return ret
         if __salt__["mysql.grant_revoke"](
             grant, database, user, host, grant_option, **connection_args
         ):
-            ret["comment"] = "Grant {0} on {1} for {2}@{3} has been " "revoked".format(
+            ret["comment"] = "Grant {} on {} for {}@{} has been revoked".format(
                 grant, database, user, host
             )
             ret["changes"][name] = "Absent"
@@ -260,8 +258,9 @@ def absent(
             err = _get_mysql_error()
             if err is not None:
                 ret["comment"] = (
-                    "Unable to revoke grant {0} on {1} for "
-                    "{2}@{3} ({4})".format(grant, database, user, host, err)
+                    "Unable to revoke grant {} on {} for {}@{} ({})".format(
+                        grant, database, user, host, err
+                    )
                 )
                 ret["result"] = False
                 return ret
@@ -269,14 +268,17 @@ def absent(
         err = _get_mysql_error()
         if err is not None:
             ret["comment"] = (
-                "Unable to determine if grant {0} on {1} for "
-                "{2}@{3} exists ({4})".format(grant, database, user, host, err)
+                "Unable to determine if grant {} on {} for {}@{} exists ({})".format(
+                    grant, database, user, host, err
+                )
             )
             ret["result"] = False
             return ret
 
     # fallback
     ret["comment"] = (
-        "Grant {0} on {1} to {2}@{3} is not present, so it" " cannot be revoked"
-    ).format(grant, database, user, host)
+        "Grant {} on {} to {}@{} is not present, so it cannot be revoked".format(
+            grant, database, user, host
+        )
+    )
     return ret
