@@ -216,6 +216,8 @@ def present(name, **kwargs):
 
     offline
         Add the scheduled job to the Salt minion when the Salt minion is not running.
+
+        .. versionadded:: 3006.3
     """
 
     ret = {"name": name, "result": True, "changes": {}, "comment": []}
@@ -241,7 +243,7 @@ def present(name, **kwargs):
                 new_item["enabled"] = True
 
         if new_item == current_schedule[name]:
-            ret["comment"].append("Job {} in correct state".format(name))
+            ret["comment"].append(f"Job {name} in correct state")
         else:
             if "test" in __opts__ and __opts__["test"]:
                 kwargs["test"] = True
@@ -255,13 +257,14 @@ def present(name, **kwargs):
                     ret["comment"] = result["comment"]
                     return ret
                 else:
-                    ret["comment"].append("Modifying job {} in schedule".format(name))
+                    ret["comment"].append(f"Modifying job {name} in schedule")
                     ret["changes"] = result["changes"]
     else:
         if "test" in __opts__ and __opts__["test"]:
             kwargs["test"] = True
             result = __salt__["schedule.add"](name, **kwargs)
             ret["comment"].append(result["comment"])
+            ret["changes"] = {name: "added"}
         else:
             result = __salt__["schedule.add"](name, **kwargs)
             if not result["result"]:
@@ -269,7 +272,7 @@ def present(name, **kwargs):
                 ret["comment"] = result["comment"]
                 return ret
             else:
-                ret["comment"].append("Adding new job {} to schedule".format(name))
+                ret["comment"].append(f"Adding new job {name} to schedule")
                 ret["changes"] = result["changes"]
 
     ret["comment"] = "\n".join(ret["comment"])
@@ -308,10 +311,10 @@ def absent(name, **kwargs):
                 ret["comment"] = result["comment"]
                 return ret
             else:
-                ret["comment"].append("Removed job {} from schedule".format(name))
+                ret["comment"].append(f"Removed job {name} from schedule")
                 ret["changes"] = result["changes"]
     else:
-        ret["comment"].append("Job {} not present in schedule".format(name))
+        ret["comment"].append(f"Job {name} not present in schedule")
 
     ret["comment"] = "\n".join(ret["comment"])
     return ret
@@ -345,9 +348,9 @@ def enabled(name, **kwargs):
                 ret["comment"] = result["comment"]
                 return ret
             else:
-                ret["comment"].append("Enabled job {} from schedule".format(name))
+                ret["comment"].append(f"Enabled job {name} from schedule")
     else:
-        ret["comment"].append("Job {} not present in schedule".format(name))
+        ret["comment"].append(f"Job {name} not present in schedule")
 
     ret["comment"] = "\n".join(ret["comment"])
     return ret
@@ -384,9 +387,9 @@ def disabled(name, **kwargs):
                 ret["comment"] = result["comment"]
                 return ret
             else:
-                ret["comment"].append("Disabled job {} from schedule".format(name))
+                ret["comment"].append(f"Disabled job {name} from schedule")
     else:
-        ret["comment"].append("Job {} not present in schedule".format(name))
+        ret["comment"].append(f"Job {name} not present in schedule")
 
     ret["comment"] = "\n".join(ret["comment"])
     return ret
