@@ -121,6 +121,7 @@ Management of SmartOS Standalone Compute Nodes
 import json
 import logging
 import os
+from collections import OrderedDict
 
 import salt.utils.atomicfile
 import salt.utils.data
@@ -208,7 +209,7 @@ def _write_config(config):
     try:
         with salt.utils.atomicfile.atomic_open("/usbkey/config", "w") as config_file:
             config_file.write("#\n# This file was generated by salt\n#\n")
-            for prop in salt.utils.odict.OrderedDict(sorted(config.items())):
+            for prop in OrderedDict(sorted(config.items())):
                 if " " in str(config[prop]):
                     if not config[prop].startswith('"') or not config[prop].endswith(
                         '"'
@@ -230,13 +231,13 @@ def _parse_vmconfig(config, instances):
     """
     vmconfig = None
 
-    if isinstance(config, (salt.utils.odict.OrderedDict)):
-        vmconfig = salt.utils.odict.OrderedDict()
+    if isinstance(config, (OrderedDict)):
+        vmconfig = OrderedDict()
         for prop in config:
             if prop not in instances:
                 vmconfig[prop] = config[prop]
             else:
-                if not isinstance(config[prop], (salt.utils.odict.OrderedDict)):
+                if not isinstance(config[prop], (OrderedDict)):
                     continue
                 vmconfig[prop] = []
                 for instance in config[prop]:
