@@ -2,11 +2,11 @@
 IPC transport classes
 """
 
-import datetime
 import errno
 import logging
 import socket
 import time
+import warnings
 
 import tornado
 import tornado.concurrent
@@ -149,7 +149,7 @@ class IPCServer:
         self._started = True
 
     @tornado.gen.coroutine
-    def handle_stream(self, stream):
+    def handle_stream(self, stream, _StreamClosedError=StreamClosedError):
         """
         Override this to handle the streams as they arrive
 
@@ -180,7 +180,7 @@ class IPCServer:
                 return _null
 
         unpacker = salt.utils.msgpack.Unpacker(raw=False)
-        while not stream.closed():
+        while not self._closing and not stream.closed():
             try:
                 wire_bytes = yield stream.read_bytes(4096, partial=True)
                 unpacker.feed(wire_bytes)
@@ -191,7 +191,7 @@ class IPCServer:
                         body,
                         write_callback(stream, framed_msg["head"]),
                     )
-            except StreamClosedError:
+            except _StreamClosedError:
                 log.trace("Client disconnected from IPC %s", self.socket_path)
                 break
             except OSError as exc:
@@ -533,18 +533,8 @@ class IPCMessagePublisher:
 
     @tornado.gen.coroutine
     def _write(self, stream, pack):
-        timeout = self.opts.get("ipc_write_timeout", salt.defaults.IPC_WRITE_TIMEOUT)
         try:
-            yield tornado.gen.with_timeout(
-                datetime.timedelta(seconds=timeout),
-                stream.write(pack),
-                quiet_exceptions=(StreamClosedError,),
-            )
-        except tornado.gen.TimeoutError:
-            log.trace("Failed to relay event to client after %d seconds", timeout)
-            if not stream.closed():
-                stream.close()
-            self.streams.discard(stream)
+            yield stream.write(pack)
         except StreamClosedError:
             log.trace("Client disconnected from IPC %s", self.socket_path)
             self.streams.discard(stream)
@@ -655,6 +645,7 @@ class IPCMessageSubscriber(IPCClient):
         self._read_stream_future = None
         self._saved_data = []
         self._read_in_progress = Lock()
+        self._closing = False
 
     @tornado.gen.coroutine
     def _read(self, timeout, callback=None):
@@ -707,9 +698,7 @@ class IPCMessageSubscriber(IPCClient):
                 self._read_stream_future = None
             except Exception as exc:  # pylint: disable=broad-except
                 log.error(
-                    "Exception occurred in Subscriber while handling stream: %s",
-                    exc,
-                    exc_info_on_level=logging.DEBUG,
+                    "Exception occurred in Subscriber while handling stream: %s", exc
                 )
                 self._read_stream_future = None
                 exc_to_raise = exc
@@ -798,3 +787,14 @@ class IPCMessageSubscriber(IPCClient):
             exc = self._read_stream_future.exception()
             if exc and not isinstance(exc, StreamClosedError):
                 log.error("Read future returned exception %r", exc)
+
+    # pylint: disable=W1701
+    def __del__(self):
+        if not self._closing:
+            warnings.warn(
+                f"unclosed ipc message subscriber {self!r}",
+                ResourceWarning,
+                source=self,
+            )
+
+    # pylint: enable=W1701
