@@ -24,26 +24,23 @@ Example Usage:
 .. versionadded:: 2015.8.0
 """
 
-
 import hashlib
 import logging
 import sys
 from functools import partial
 
-import salt.loader_context
+import salt.loader.context
 import salt.utils.stringutils
 import salt.utils.versions
 from salt.exceptions import SaltInvocationError
-from salt.ext.six.moves import range  # pylint: disable=import-error,redefined-builtin
 
 # pylint: disable=import-error
 try:
     # pylint: disable=import-error
-    import boto
     import boto3
-    import boto.exception
     import boto3.session
     import botocore  # pylint: disable=W0611
+    import botocore.exceptions
 
     # pylint: enable=import-error
     logging.getLogger("boto3").setLevel(logging.CRITICAL)
@@ -56,7 +53,7 @@ except ImportError:
 log = logging.getLogger(__name__)
 
 __virtualname__ = "boto3"
-__salt_loader__ = salt.loader_context.LoaderContext()
+__salt_loader__ = salt.loader.context.LoaderContext()
 __context__ = __salt_loader__.named_context("__context__", {})
 
 
@@ -106,7 +103,7 @@ def _get_profile(service, region, key, keyid, profile):
     if not keyid and _option(service + ".keyid"):
         keyid = _option(service + ".keyid")
 
-    label = "boto_{}:".format(service)
+    label = f"boto_{service}:"
     if keyid:
         hash_string = region + keyid + key
         hash_string = salt.utils.stringutils.to_bytes(hash_string)
@@ -140,9 +137,9 @@ def cache_id(
 
     cxkey, _, _, _ = _get_profile(service, region, key, keyid, profile)
     if sub_resource:
-        cxkey = "{}:{}:{}:id".format(cxkey, sub_resource, name)
+        cxkey = f"{cxkey}:{sub_resource}:{name}:id"
     else:
-        cxkey = "{}:{}:id".format(cxkey, name)
+        cxkey = f"{cxkey}:{name}:id"
 
     if invalidate:
         if cxkey in __context__:
@@ -199,11 +196,11 @@ def get_connection(
             aws_access_key_id=keyid, aws_secret_access_key=key, region_name=region
         )
         if session is None:
-            raise SaltInvocationError('Region "{}" is not ' "valid.".format(region))
+            raise SaltInvocationError(f'Region "{region}" is not valid.')
         conn = session.client(module)
         if conn is None:
-            raise SaltInvocationError('Region "{}" is not ' "valid.".format(region))
-    except boto.exception.NoAuthHandlerFound:
+            raise SaltInvocationError(f'Region "{region}" is not valid.')
+    except botocore.exceptions.NoCredentialsError:
         raise SaltInvocationError(
             "No authentication credentials found when "
             "attempting to make boto {} connection to "
@@ -312,6 +309,5 @@ def ordered(obj):
 
 
 def json_objs_equal(left, right):
-    """ Compare two parsed JSON objects, given non-ordering in JSON objects
-    """
+    """Compare two parsed JSON objects, given non-ordering in JSON objects"""
     return ordered(left) == ordered(right)
