@@ -8,7 +8,6 @@ This util provides access to an idem-ready hub
 """
 
 import logging
-import sys
 
 try:
     import pop.hub
@@ -23,8 +22,6 @@ __virtualname__ = "idem"
 
 
 def __virtual__():
-    if sys.version_info < (3, 6):
-        return False, "idem only works on python3.6 and later"
     if not HAS_POP[0]:
         return HAS_POP
     return __virtualname__
