@@ -1,13 +1,9 @@
-# -*- coding: utf-8 -*-
 """
 Application Kinds of Salt apps.
 These are used to indicate what kind of Application is using RAET
 """
-from __future__ import absolute_import, unicode_literals
 
-from collections import namedtuple
-
-from salt.utils.odict import OrderedDict
+from collections import OrderedDict, namedtuple
 
 # Python equivalent of an enum
 APPL_KINDS = OrderedDict([("master", 0), ("minion", 1), ("syndic", 2), ("caller", 3)])
