@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 r"""
 A salt util for modifying firewall settings.
 
@@ -7,16 +6,24 @@ A salt util for modifying firewall settings.
 
 This util allows you to modify firewall settings in the local group policy in
 addition to the normal firewall settings. Parameters are taken from the
-netsh advfirewall prompt.
+netsh advfirewall prompt. This utility has been adapted to use powershell
+instead of the ``netsh`` command to make it compatible with non-English systems.
+It maintains the ``netsh`` commands and parameters, but it is using powershell
+under the hood.
+
+.. versionchanged:: 3008.0
 
 .. note::
     More information can be found in the advfirewall context in netsh. This can
-    be access by opening a netsh prompt. At a command prompt type the following:
+    be accessed by opening a netsh prompt. At a command prompt type the
+    following:
 
-    c:\>netsh
-    netsh>advfirewall
-    netsh advfirewall>set help
-    netsh advfirewall>set domain help
+    .. code-block:: powershell
+
+        c:\>netsh
+        netsh>advfirewall
+        netsh advfirewall>set help
+        netsh advfirewall>set domain help
 
 Usage:
 
@@ -66,93 +73,116 @@ Usage:
                                                     outbound='allowoutbound',
                                                     store='lgpo')
 """
-# Import Python libs
-from __future__ import absolute_import, print_function, unicode_literals
 
-import logging
-import os
-import re
-import socket
-import tempfile
-from textwrap import dedent
-
-import salt.modules.cmdmod
+import salt.utils.platform
+import salt.utils.win_pwsh
 from salt.exceptions import CommandExecutionError
-from salt.ext.six.moves import zip
 
-log = logging.getLogger(__name__)
-__hostname__ = socket.gethostname()
-__virtualname__ = "netsh"
+ON_OFF = {
+    0: "OFF",
+    1: "ON",
+    2: "NotConfigured",
+    "off": "False",
+    "on": "True",
+    "notconfigured": "NotConfigured",
+}
+
+ENABLE_DISABLE = {
+    0: "Disable",
+    1: "Enable",
+    2: "NotConfigured",
+    "disable": 0,
+    "enable": 1,
+    "notconfigured": 2,
+}
+OUTBOUND = {
+    0: "NotConfigured",
+    2: "AllowOutbound",
+    4: "BlockOutbound",
+    "notconfigured": "NotConfigured",
+    "allowoutbound": "Allow",
+    "blockoutbound": "Block",
+}
 
 
-# Although utils are often directly imported, it is also possible to use the
-# loader.
-def __virtual__():
+def _get_inbound_text(rule, action):
     """
-    Only load if on a Windows system
+    The "Inbound connections" setting is a combination of 2 parameters:
+
+    - AllowInboundRules
+      0 = False
+      1 = True
+      2 = NotConfigured
+      I don't see a way to set "AllowInboundRules" outside of PowerShell
+
+    - DefaultInboundAction
+      0 = Not Configured
+      2 = Allow Inbound
+      4 = Block Inbound
+
+    The settings are as follows:
+
+    Rules Action
+    0     4       BlockInboundAlways
+    1     0       NotConfigured
+    1     2       AllowInbound
+    1     4       BlockInbound
+    2     0       NotConfigured
+    2     2       AllowInbound
+    2     4       BlockInbound
     """
-    if not salt.utils.platform.is_windows():
-        return False, "This utility only available on Windows"
-
-    return __virtualname__
+    settings = {
+        0: {
+            0: "NotConfigured",
+            2: "AllowInbound",
+            4: "BlockInboundAlways",
+        },
+        1: {
+            0: "NotConfigured",
+            2: "AllowInbound",
+            4: "BlockInbound",
+        },
+        2: {
+            0: "NotConfigured",
+            2: "AllowInbound",
+            4: "BlockInbound",
+        },
+    }
+    return settings[rule][action]
 
 
-def _netsh_file(content):
-    """
-    helper function to get the results of ``netsh -f content.txt``
-
-    Running ``netsh`` will drop you into a ``netsh`` prompt where you can issue
-    ``netsh`` commands. You can put a series of commands in an external file and
-    run them as if from a ``netsh`` prompt using the ``-f`` switch. That's what
-    this function does.
-
-    Args:
-
-        content (str):
-            The contents of the file that will be run by the ``netsh -f``
-            command
-
-    Returns:
-        str: The text returned by the netsh command
-    """
-    with tempfile.NamedTemporaryFile(
-        mode="w", prefix="salt-", suffix=".netsh", delete=False, encoding="utf-8"
-    ) as fp:
-        fp.write(content)
-    try:
-        log.debug("%s:\n%s", fp.name, content)
-        return salt.modules.cmdmod.run(
-            "netsh -f {0}".format(fp.name), python_shell=True
-        )
-    finally:
-        os.remove(fp.name)
+def _get_inbound_settings(text):
+    settings = {
+        "allowinbound": (2, 2),
+        "blockinbound": (2, 4),
+        "blockinboundalways": (0, 4),
+        "notconfigured": (2, 0),
+    }
+    return settings[text.lower()]
 
 
-def _netsh_command(command, store):
-    if store.lower() not in ("local", "lgpo"):
-        raise ValueError("Incorrect store: {0}".format(store))
-    # set the store for local or lgpo
-    if store.lower() == "local":
-        netsh_script = dedent(
-            """\
-            advfirewall
-            set store local
-            {0}
-        """.format(
-                command
-            )
-        )
-    else:
-        netsh_script = dedent(
-            """\
-            advfirewall
-            set store gpo = {0}
-            {1}
-        """.format(
-                __hostname__, command
-            )
-        )
-    return _netsh_file(content=netsh_script).splitlines()
+def _get_all_settings(profile, store="local"):
+    # Get current settings using PowerShell
+    # if "lgpo.firewall_profile_settings" not in __context__:
+    cmd = ["Get-NetFirewallProfile"]
+    if profile:
+        cmd.append(profile)
+    if store.lower() == "lgpo":
+        cmd.extend(["-PolicyStore", "localhost"])
+
+    # Run the command and get dict
+    settings = salt.utils.win_pwsh.run_dict(cmd)
+
+    # A successful run should return a dictionary
+    if not settings:
+        raise CommandExecutionError("LGPO NETSH: An unknown error occurred")
+
+    # Remove the junk
+    for setting in list(settings.keys()):
+        if setting.startswith("Cim"):
+            settings.pop(setting)
+
+    return settings
 
 
 def get_settings(profile, section, store="local"):
@@ -196,75 +226,42 @@ def get_settings(profile, section, store="local"):
     """
     # validate input
     if profile.lower() not in ("domain", "public", "private"):
-        raise ValueError("Incorrect profile: {0}".format(profile))
+        raise ValueError(f"Incorrect profile: {profile}")
     if section.lower() not in ("state", "firewallpolicy", "settings", "logging"):
-        raise ValueError("Incorrect section: {0}".format(section))
+        raise ValueError(f"Incorrect section: {section}")
     if store.lower() not in ("local", "lgpo"):
-        raise ValueError("Incorrect store: {0}".format(store))
-    command = "show {0}profile {1}".format(profile, section)
-    # run it
-    results = _netsh_command(command=command, store=store)
-    # sample output:
-    # Domain Profile Settings:
-    # ----------------------------------------------------------------------
-    # LocalFirewallRules                    N/A (GPO-store only)
-    # LocalConSecRules                      N/A (GPO-store only)
-    # InboundUserNotification               Disable
-    # RemoteManagement                      Disable
-    # UnicastResponseToMulticast            Enable
+        raise ValueError(f"Incorrect store: {store}")
 
-    # if it's less than 3 lines it failed
-    if len(results) < 3:
-        raise CommandExecutionError("Invalid results: {0}".format(results))
-    ret = {}
-    # Skip the first 2 lines. Add everything else to a dictionary
-    for line in results[3:]:
-        ret.update(dict(list(zip(*[iter(re.split(r"\s{2,}", line))] * 2))))
+    settings = _get_all_settings(profile=profile, store=store)
 
-    # Remove spaces from the values so that `Not Configured` is detected
-    # correctly
-    for item in ret:
-        ret[item] = ret[item].replace(" ", "")
+    # Make it look like netsh output
+    ret_settings = {
+        "firewallpolicy": {
+            "Inbound": _get_inbound_text(
+                settings["AllowInboundRules"], settings["DefaultInboundAction"]
+            ),
+            "Outbound": OUTBOUND[settings["DefaultOutboundAction"]],
+        },
+        "state": {
+            "State": ON_OFF[settings["Enabled"]],
+        },
+        "logging": {
+            "FileName": settings["LogFileName"],
+            "LogAllowedConnections": ENABLE_DISABLE[settings["LogAllowed"]],
+            "LogDroppedConnections": ENABLE_DISABLE[settings["LogBlocked"]],
+            "MaxFileSize": settings["LogMaxSizeKilobytes"],
+        },
+        "settings": {
+            "InboundUserNotification": ENABLE_DISABLE[settings["NotifyOnListen"]],
+            "LocalConSecRules": ENABLE_DISABLE[settings["AllowLocalIPsecRules"]],
+            "LocalFirewallRules": ENABLE_DISABLE[settings["AllowLocalFirewallRules"]],
+            "UnicastResponseToMulticast": ENABLE_DISABLE[
+                settings["AllowUnicastResponseToMulticast"]
+            ],
+        },
+    }
 
-    # special handling for firewallpolicy
-    if section == "firewallpolicy":
-        inbound, outbound = ret["Firewall Policy"].split(",")
-        return {"Inbound": inbound, "Outbound": outbound}
-
-    return ret
-
-
-def get_all_settings(profile, store="local"):
-    """
-    Gets all the properties for the specified profile in the specified store
-
-    Args:
-
-        profile (str):
-            The firewall profile to query. Valid options are:
-
-            - domain
-            - public
-            - private
-
-        store (str):
-            The store to use. This is either the local firewall policy or the
-            policy defined by local group policy. Valid options are:
-
-            - lgpo
-            - local
-
-            Default is ``local``
-
-    Returns:
-        dict: A dictionary containing the specified settings
-    """
-    ret = dict()
-    ret.update(get_settings(profile=profile, section="state", store=store))
-    ret.update(get_settings(profile=profile, section="firewallpolicy", store=store))
-    ret.update(get_settings(profile=profile, section="settings", store=store))
-    ret.update(get_settings(profile=profile, section="logging", store=store))
-    return ret
+    return ret_settings[section.lower()]
 
 
 def get_all_profiles(store="local"):
@@ -292,6 +289,65 @@ def get_all_profiles(store="local"):
     }
 
 
+def get_all_settings(profile, store="local"):
+    """
+    Gets all the properties for the specified profile in the specified store
+
+    Args:
+
+        profile (str):
+            The firewall profile to query. Valid options are:
+
+            - domain
+            - public
+            - private
+
+        store (str):
+            The store to use. This is either the local firewall policy or the
+            policy defined by local group policy. Valid options are:
+
+            - lgpo
+            - local
+
+            Default is ``local``
+
+    Returns:
+        dict: A dictionary containing the specified settings
+
+    Raises:
+        CommandExecutionError: If an error occurs
+        ValueError: If the parameters are incorrect
+    """
+    # validate input
+    if profile.lower() not in ("domain", "public", "private"):
+        raise ValueError(f"Incorrect profile: {profile}")
+    if store.lower() not in ("local", "lgpo"):
+        raise ValueError(f"Incorrect store: {store}")
+
+    settings = _get_all_settings(profile=profile, store=store)
+
+    # Make it look like netsh output
+    ret_settings = {
+        "FileName": settings["LogFileName"],
+        "Inbound": _get_inbound_text(
+            settings["AllowInboundRules"], settings["DefaultInboundAction"]
+        ),
+        "InboundUserNotification": ENABLE_DISABLE[settings["NotifyOnListen"]],
+        "LocalConSecRules": ENABLE_DISABLE[settings["AllowLocalIPsecRules"]],
+        "LocalFirewallRules": ENABLE_DISABLE[settings["AllowLocalFirewallRules"]],
+        "LogAllowedConnections": ENABLE_DISABLE[settings["LogAllowed"]],
+        "LogDroppedConnections": ENABLE_DISABLE[settings["LogBlocked"]],
+        "MaxFileSize": settings["LogMaxSizeKilobytes"],
+        "Outbound": OUTBOUND[settings["DefaultOutboundAction"]],
+        "State": ON_OFF[settings["Enabled"]],
+        "UnicastResponseToMulticast": ON_OFF[
+            settings["AllowUnicastResponseToMulticast"]
+        ],
+    }
+
+    return ret_settings
+
+
 def set_firewall_settings(profile, inbound=None, outbound=None, store="local"):
     """
     Set the firewall inbound/outbound settings for the specified profile and
@@ -313,7 +369,7 @@ def set_firewall_settings(profile, inbound=None, outbound=None, store="local"):
             - blockinbound
             - blockinboundalways
             - allowinbound
-            - notconfigured
+            - notconfigured  <=== lgpo only
 
             Default is ``None``
 
@@ -323,7 +379,7 @@ def set_firewall_settings(profile, inbound=None, outbound=None, store="local"):
 
             - allowoutbound
             - blockoutbound
-            - notconfigured
+            - notconfigured  <=== lgpo only
 
             Default is ``None``
 
@@ -345,41 +401,65 @@ def set_firewall_settings(profile, inbound=None, outbound=None, store="local"):
     """
     # Input validation
     if profile.lower() not in ("domain", "public", "private"):
-        raise ValueError("Incorrect profile: {0}".format(profile))
+        raise ValueError(f"Incorrect profile: {profile}")
     if inbound and inbound.lower() not in (
         "blockinbound",
         "blockinboundalways",
         "allowinbound",
         "notconfigured",
     ):
-        raise ValueError("Incorrect inbound value: {0}".format(inbound))
+        raise ValueError(f"Incorrect inbound value: {inbound}")
     if outbound and outbound.lower() not in (
         "allowoutbound",
         "blockoutbound",
         "notconfigured",
     ):
-        raise ValueError("Incorrect outbound value: {0}".format(outbound))
+        raise ValueError(f"Incorrect outbound value: {outbound}")
     if not inbound and not outbound:
         raise ValueError("Must set inbound or outbound")
 
-    # You have to specify inbound and outbound setting at the same time
-    # If you're only specifying one, you have to get the current setting for the
-    # other
-    if not inbound or not outbound:
-        ret = get_settings(profile=profile, section="firewallpolicy", store=store)
-        if not inbound:
-            inbound = ret["Inbound"]
-        if not outbound:
-            outbound = ret["Outbound"]
+    # https://learn.microsoft.com/en-us/powershell/module/netsecurity/set-netfirewallprofile?view=windowsserver2025-ps#-allowinboundrules
+    # https://learn.microsoft.com/en-us/powershell/module/netsecurity/set-netfirewallprofile?view=windowsserver2025-ps#-defaultoutboundaction
+    if store == "local":
+        if inbound and inbound.lower() == "notconfigured":
+            msg = "Cannot set local inbound policies as NotConfigured"
+            raise CommandExecutionError(msg)
+        if outbound and outbound.lower() == "notconfigured":
+            msg = "Cannot set local outbound policies as NotConfigured"
+            raise CommandExecutionError(msg)
 
-    command = "set {0}profile firewallpolicy {1},{2}" "".format(
-        profile, inbound, outbound
-    )
+    # Get current settings
+    settings = _get_all_settings(profile=profile, store=store)
 
-    results = _netsh_command(command=command, store=store)
+    # Build the powershell command
+    cmd = ["Set-NetFirewallProfile"]
+    if profile:
+        cmd.append(profile)
+    if store.lower() == "lgpo":
+        cmd.extend(["-PolicyStore", "localhost"])
 
+    # Get inbound settings
+    if inbound:
+        in_rule, in_action = _get_inbound_settings(inbound.lower())
+        # If current AllowInboundRules is set (1 or 2) and new AllowInboundRules is 2
+        # We want to just keep the current setting.
+        # We don't have a way in LGPO to set the AllowInboundRules. I can't find it in
+        # gpedit.msc either. Not sure how to set it outside of PowerShell
+        current_in_rule = settings["AllowInboundRules"]
+        if current_in_rule > 0 and in_rule == 2:
+            in_rule = current_in_rule
+        cmd.extend(["-AllowInboundRules", in_rule, "-DefaultInboundAction", in_action])
+
+    if outbound:
+        out_rule = OUTBOUND[outbound.lower()]
+        cmd.extend(["-DefaultOutboundAction", out_rule])
+
+    # Run the command
+    results = salt.utils.win_pwsh.run_dict(cmd)
+
+    # A successful run should return an empty list
     if results:
-        raise CommandExecutionError("An error occurred: {0}".format(results))
+        raise CommandExecutionError(f"An error occurred: {results}")
 
     return True
 
@@ -449,35 +529,64 @@ def set_logging_settings(profile, setting, value, store="local"):
     """
     # Input validation
     if profile.lower() not in ("domain", "public", "private"):
-        raise ValueError("Incorrect profile: {0}".format(profile))
+        raise ValueError(f"Incorrect profile: {profile}")
     if setting.lower() not in (
         "allowedconnections",
         "droppedconnections",
         "filename",
         "maxfilesize",
     ):
-        raise ValueError("Incorrect setting: {0}".format(setting))
+        raise ValueError(f"Incorrect setting: {setting}")
+
+    # https://learn.microsoft.com/en-us/powershell/module/netsecurity/set-netfirewallprofile?view=windowsserver2025-ps#-logallowed
+    # https://learn.microsoft.com/en-us/powershell/module/netsecurity/set-netfirewallprofile?view=windowsserver2025-ps#-logblocked
+    # https://learn.microsoft.com/en-us/powershell/module/netsecurity/set-netfirewallprofile?view=windowsserver2025-ps#-logmaxsizekilobytes
+    if str(value).lower() == "notconfigured" and store.lower() == "local":
+        if setting in ["allowedconnections", "droppedconnections", "maxfilesize"]:
+            raise CommandExecutionError(
+                "NotConfigured only valid when setting Group Policy"
+            )
+    if setting == "maxfilesize" and str(value).lower() == "notconfigured":
+        raise CommandExecutionError(f"NotConfigured not a valid option for {setting}")
+
+    settings = {"filename": ["-LogFileName", value]}
     if setting.lower() in ("allowedconnections", "droppedconnections"):
         if value.lower() not in ("enable", "disable", "notconfigured"):
-            raise ValueError("Incorrect value: {0}".format(value))
+            raise ValueError(f"Incorrect value: {value}")
+        settings.update(
+            {
+                "allowedconnections": ["-LogAllowed", ENABLE_DISABLE[value.lower()]],
+                "droppedconnections": ["-LogBlocked", ENABLE_DISABLE[value.lower()]],
+            }
+        )
+
     # TODO: Consider adding something like the following to validate filename
     # https://stackoverflow.com/questions/9532499/check-whether-a-path-is-valid-in-python-without-creating-a-file-at-the-paths-ta
     if setting.lower() == "maxfilesize":
-        if value.lower() != "notconfigured":
+        if str(value).lower() != "notconfigured":
             # Must be a number between 1 and 32767
             try:
                 int(value)
             except ValueError:
-                raise ValueError("Incorrect value: {0}".format(value))
+                raise ValueError(f"Incorrect value: {value}")
             if not 1 <= int(value) <= 32767:
-                raise ValueError("Incorrect value: {0}".format(value))
-    # Run the command
-    command = "set {0}profile logging {1} {2}".format(profile, setting, value)
-    results = _netsh_command(command=command, store=store)
+                raise ValueError(f"Incorrect value: {value}")
+        settings.update({"maxfilesize": ["-LogMaxSizeKilobytes", value]})
+
+    # Build the powershell command
+    cmd = ["Set-NetFirewallProfile"]
+    if profile:
+        cmd.append(profile)
+    if store and store.lower() == "lgpo":
+        cmd.extend(["-PolicyStore", "localhost"])
+
+    cmd.extend(settings[setting.lower()])
+
+    results = salt.utils.win_pwsh.run_dict(cmd)
 
     # A successful run should return an empty list
     if results:
-        raise CommandExecutionError("An error occurred: {0}".format(results))
+        raise CommandExecutionError(f"An error occurred: {results}")
 
     return True
 
@@ -501,7 +610,6 @@ def set_settings(profile, setting, value, store="local"):
             - localfirewallrules
             - localconsecrules
             - inboundusernotification
-            - remotemanagement
             - unicastresponsetomulticast
 
         value (str):
@@ -509,7 +617,7 @@ def set_settings(profile, setting, value, store="local"):
 
             - enable
             - disable
-            - notconfigured
+            - notconfigured  <== lgpo only
 
         store (str):
             The store to use. This is either the local firewall policy or the
@@ -529,32 +637,57 @@ def set_settings(profile, setting, value, store="local"):
     """
     # Input validation
     if profile.lower() not in ("domain", "public", "private"):
-        raise ValueError("Incorrect profile: {0}".format(profile))
+        raise ValueError(f"Incorrect profile: {profile}")
     if setting.lower() not in (
         "localfirewallrules",
         "localconsecrules",
         "inboundusernotification",
-        "remotemanagement",
         "unicastresponsetomulticast",
     ):
-        raise ValueError("Incorrect setting: {0}".format(setting))
+        raise ValueError(f"Incorrect setting: {setting}")
     if value.lower() not in ("enable", "disable", "notconfigured"):
-        raise ValueError("Incorrect value: {0}".format(value))
+        raise ValueError(f"Incorrect value: {value}")
+    # https://learn.microsoft.com/en-us/powershell/module/netsecurity/set-netfirewallprofile?view=windowsserver2025-ps#-allowlocalfirewallrules
+    # https://learn.microsoft.com/en-us/powershell/module/netsecurity/set-netfirewallprofile?view=windowsserver2025-ps#-allowlocalipsecrules
+    # https://learn.microsoft.com/en-us/powershell/module/netsecurity/set-netfirewallprofile?view=windowsserver2025-ps#-allowunicastresponsetomulticast
+    # https://learn.microsoft.com/en-us/powershell/module/netsecurity/set-netfirewallprofile?view=windowsserver2025-ps#-notifyonlisten
+    if value.lower() == "notconfigured" and store.lower() == "local":
+        msg = "NotConfigured is only valid when setting group policy"
+        raise CommandExecutionError(msg)
 
-    # Run the command
-    command = "set {0}profile settings {1} {2}".format(profile, setting, value)
-    results = _netsh_command(command=command, store=store)
+    # Build the powershell command
+    cmd = ["Set-NetFirewallProfile"]
+    if profile:
+        cmd.append(profile)
+    if store.lower() == "lgpo":
+        cmd.extend(["-PolicyStore", "localhost"])
+
+    settings = {
+        "localfirewallrules": [
+            "-AllowLocalFirewallRules",
+            ENABLE_DISABLE[value.lower()],
+        ],
+        "localconsecrules": ["-AllowLocalIPsecRules", ENABLE_DISABLE[value.lower()]],
+        "inboundusernotification": ["-NotifyOnListen", ENABLE_DISABLE[value.lower()]],
+        "unicastresponsetomulticast": [
+            "-AllowUnicastResponseToMulticast",
+            ENABLE_DISABLE[value.lower()],
+        ],
+    }
+    cmd.extend(settings[setting.lower()])
+
+    results = salt.utils.win_pwsh.run_dict(cmd)
 
     # A successful run should return an empty list
     if results:
-        raise CommandExecutionError("An error occurred: {0}".format(results))
+        raise CommandExecutionError(f"An error occurred: {results}")
 
     return True
 
 
 def set_state(profile, state, store="local"):
     """
-    Configure the firewall state.
+    Enable or disable the firewall profile.
 
     Args:
 
@@ -590,16 +723,26 @@ def set_state(profile, state, store="local"):
     """
     # Input validation
     if profile.lower() not in ("domain", "public", "private"):
-        raise ValueError("Incorrect profile: {0}".format(profile))
-    if state.lower() not in ("on", "off", "notconfigured"):
-        raise ValueError("Incorrect state: {0}".format(state))
+        raise ValueError(f"Incorrect profile: {profile}")
+    if not isinstance(state, bool):
+        if state.lower() not in ("on", "off", "notconfigured"):
+            raise ValueError(f"Incorrect state: {state}")
+    else:
+        state = "On" if state else "Off"
 
-    # Run the command
-    command = "set {0}profile state {1}".format(profile, state)
-    results = _netsh_command(command=command, store=store)
+    # Build the powershell command
+    cmd = ["Set-NetFirewallProfile"]
+    if profile:
+        cmd.append(profile)
+    if store.lower() == "lgpo":
+        cmd.extend(["-PolicyStore", "localhost"])
+
+    cmd.extend(["-Enabled", ON_OFF[state.lower()]])
+
+    results = salt.utils.win_pwsh.run_dict(cmd)
 
     # A successful run should return an empty list
     if results:
-        raise CommandExecutionError("An error occurred: {0}".format(results))
+        raise CommandExecutionError(f"An error occurred: {results}")
 
     return True
