@@ -70,12 +70,15 @@ def split_username(username):
     Splits out the username from the domain name and returns both.
     """
     domain = "."
-    user_name = username
-    if "@" in username:
-        user_name, domain = username.split("@")
-    if "\\" in username:
-        domain, user_name = username.split("\\")
-    return user_name, domain
+    user_name = str(username)
+    # Domain users with User Principal Name (UPN): user@DOMAIN
+    if "@" in user_name:
+        user_name, domain = user_name.split("@", maxsplit=1)
+        domain = domain.removesuffix(".local")
+    # Domain users with Down-Level Logon Name: DOMAIN\user
+    if "\\" in user_name:
+        domain, user_name = user_name.split("\\", maxsplit=1)
+    return str(user_name), str(domain)
 
 
 def create_env(user_token, inherit, timeout=1):
